@media (prefers-color-scheme: dark) {
    /*
    Generated by https://darkreader.org
    Instructions: Install the extension on a Chromium-based browser
    Then do this to export the CSS: https://git.io/JOM6t and drop it here
    Some color values where manually changed - just search for "/*" in this file and insert them in the new css
    */
    /* User-Agent Style */
    html {
        background-color: #181a1b !important;
    }
    html, body, input, textarea, select, button {
        background-color: #181a1b;
    }
    html, body, input, textarea, select, button {
        border-color: #736b5e;
        color: #e8e6e3;
    }
    a {
        color: #3391ff;
    }
    table {
        border-color: #545b5e;
    }
    ::placeholder {
        color: #b2aba1;
    }
    input:-webkit-autofill,
    textarea:-webkit-autofill,
    select:-webkit-autofill {
        background-color: #555b00 !important;
        color: #e8e6e3 !important;
    }
    ::-webkit-scrollbar {
        background-color: #202324;
        color: #aba499;
    }
    ::-webkit-scrollbar-thumb {
        background-color: #454a4d;
    }
    ::-webkit-scrollbar-thumb:hover {
        background-color: #575e62;
    }
    ::-webkit-scrollbar-thumb:active {
        background-color: #484e51;
    }
    ::-webkit-scrollbar-corner {
        background-color: #181a1b;
    }
    ::selection {
        background-color: #004daa !important;
        color: #e8e6e3 !important;
    }
    ::-moz-selection {
        background-color: #004daa !important;
        color: #e8e6e3 !important;
    }

    /* Invert Style */
    .jfk-bubble.gtx-bubble, .captcheck_answer_label > input + img, span#closed_text > img[src^="https://www.gstatic.com/images/branding/googlelogo"], span[data-href^="https://www.hcaptcha.com/"] > #icon, #bit-notification-bar-iframe, embed[type="application/pdf"] {
        filter: invert(100%) hue-rotate(180deg) contrast(90%) !important;
    }

    /* Variables Style */
    :root {
       --darkreader-neutral-background: #131516;
       --darkreader-neutral-text: #d8d4cf;
       --darkreader-selection-background: #004daa;
       --darkreader-selection-text: #e8e6e3;
    }

    /* Modified CSS */
    a:active,
    a:hover {
        outline-color: initial;
    }
    abbr[title] {
        border-bottom-color: initial;
    }
    ins {
        background-image: initial;
        background-color: rgb(112, 112, 0);
        text-decoration-color: initial;
    }
    ins,
    mark {
        color: rgb(232, 230, 227);
    }
    mark {
        background-image: initial;
        background-color: rgb(204, 204, 0);
    }
    dl,
    ol,
    ul {
        list-style-image: none;
    }
    li {
        list-style-image: initial;
    }
    img {
        border-color: initial;
    }
    .chromeframe {
        background-image: initial;
        background-color: rgb(53, 57, 59);
        color: rgb(232, 230, 227);
    }
    .ir {
        border-color: initial;
        background-color: transparent;
    }
    .visuallyhidden {
        border-color: initial;
    }
    .fa-border {
        border-color: rgb(53, 57, 59);
    }
    .fa-inverse {
        color: rgb(232, 230, 227);
    }
    .sr-only {
        border-color: initial;
    }
    .fa::before,
    .icon::before,
    .rst-content .admonition-title::before,
    .rst-content .code-block-caption .headerlink::before,
    .rst-content code.download span:first-child::before,
    .rst-content dl dt .headerlink::before,
    .rst-content h1 .headerlink::before,
    .rst-content h2 .headerlink::before,
    .rst-content h3 .headerlink::before,
    .rst-content h4 .headerlink::before,
    .rst-content h5 .headerlink::before,
    .rst-content h6 .headerlink::before,
    .rst-content p.caption .headerlink::before,
    .rst-content table > caption .headerlink::before,
    .rst-content tt.download span:first-child::before,
    .wy-dropdown .caret::before,
    .wy-inline-validate.wy-inline-validate-danger .wy-input-context::before,
    .wy-inline-validate.wy-inline-validate-info .wy-input-context::before,
    .wy-inline-validate.wy-inline-validate-success .wy-input-context::before,
    .wy-inline-validate.wy-inline-validate-warning .wy-input-context::before,
    .wy-menu-vertical li.current > a span.toctree-expand::before,
    .wy-menu-vertical li.on a span.toctree-expand::before,
    .wy-menu-vertical li span.toctree-expand::before {
        text-decoration-color: inherit;
    }
    .rst-content .code-block-caption a .headerlink,
    .rst-content a .admonition-title,
    .rst-content code.download a span:first-child,
    .rst-content dl dt a .headerlink,
    .rst-content h1 a .headerlink,
    .rst-content h2 a .headerlink,
    .rst-content h3 a .headerlink,
    .rst-content h4 a .headerlink,
    .rst-content h5 a .headerlink,
    .rst-content h6 a .headerlink,
    .rst-content p.caption a .headerlink,
    .rst-content table > caption a .headerlink,
    .rst-content tt.download a span:first-child,
    .wy-menu-vertical li.current > a span.toctree-expand,
    .wy-menu-vertical li.on a span.toctree-expand,
    .wy-menu-vertical li a span.toctree-expand,
    a .fa,
    a .icon,
    a .rst-content .admonition-title,
    a .rst-content .code-block-caption .headerlink,
    a .rst-content code.download span:first-child,
    a .rst-content dl dt .headerlink,
    a .rst-content h1 .headerlink,
    a .rst-content h2 .headerlink,
    a .rst-content h3 .headerlink,
    a .rst-content h4 .headerlink,
    a .rst-content h5 .headerlink,
    a .rst-content h6 .headerlink,
    a .rst-content p.caption .headerlink,
    a .rst-content table > caption .headerlink,
    a .rst-content tt.download span:first-child,
    a .wy-menu-vertical li span.toctree-expand {
        text-decoration-color: inherit;
    }
    .rst-content .admonition,
    .rst-content .admonition-todo,
    .rst-content .attention,
    .rst-content .caution,
    .rst-content .danger,
    .rst-content .error,
    .rst-content .hint,
    .rst-content .important,
    .rst-content .note,
    .rst-content .seealso,
    .rst-content .tip,
    .rst-content .warning,
    .wy-alert {
        background-image: initial;
        background-color: rgb(32, 35, 36);
    }
    .rst-content .admonition-title,
    .wy-alert-title {
        color: rgb(232, 230, 227);
        background-image: initial;
        background-color: rgb(29, 91, 131);
    }
    .rst-content .danger,
    .rst-content .error,
    .rst-content .wy-alert-danger.admonition,
    .rst-content .wy-alert-danger.admonition-todo,
    .rst-content .wy-alert-danger.attention,
    .rst-content .wy-alert-danger.caution,
    .rst-content .wy-alert-danger.hint,
    .rst-content .wy-alert-danger.important,
    .rst-content .wy-alert-danger.note,
    .rst-content .wy-alert-danger.seealso,
    .rst-content .wy-alert-danger.tip,
    .rst-content .wy-alert-danger.warning,
    .wy-alert.wy-alert-danger {
        background-image: initial;
        background-color: rgb(52, 12, 8);
    }
    .rst-content .danger .admonition-title,
    .rst-content .danger .wy-alert-title,
    .rst-content .error .admonition-title,
    .rst-content .error .wy-alert-title,
    .rst-content .wy-alert-danger.admonition-todo .admonition-title,
    .rst-content .wy-alert-danger.admonition-todo .wy-alert-title,
    .rst-content .wy-alert-danger.admonition .admonition-title,
    .rst-content .wy-alert-danger.admonition .wy-alert-title,
    .rst-content .wy-alert-danger.attention .admonition-title,
    .rst-content .wy-alert-danger.attention .wy-alert-title,
    .rst-content .wy-alert-danger.caution .admonition-title,
    .rst-content .wy-alert-danger.caution .wy-alert-title,
    .rst-content .wy-alert-danger.hint .admonition-title,
    .rst-content .wy-alert-danger.hint .wy-alert-title,
    .rst-content .wy-alert-danger.important .admonition-title,
    .rst-content .wy-alert-danger.important .wy-alert-title,
    .rst-content .wy-alert-danger.note .admonition-title,
    .rst-content .wy-alert-danger.note .wy-alert-title,
    .rst-content .wy-alert-danger.seealso .admonition-title,
    .rst-content .wy-alert-danger.seealso .wy-alert-title,
    .rst-content .wy-alert-danger.tip .admonition-title,
    .rst-content .wy-alert-danger.tip .wy-alert-title,
    .rst-content .wy-alert-danger.warning .admonition-title,
    .rst-content .wy-alert-danger.warning .wy-alert-title,
    .rst-content .wy-alert.wy-alert-danger .admonition-title,
    .wy-alert.wy-alert-danger .rst-content .admonition-title,
    .wy-alert.wy-alert-danger .wy-alert-title {
        background-image: initial;
        background-color: rgb(108, 22, 13);
    }
    .rst-content .admonition-todo,
    .rst-content .attention,
    .rst-content .caution,
    .rst-content .warning,
    .rst-content .wy-alert-warning.admonition,
    .rst-content .wy-alert-warning.danger,
    .rst-content .wy-alert-warning.error,
    .rst-content .wy-alert-warning.hint,
    .rst-content .wy-alert-warning.important,
    .rst-content .wy-alert-warning.note,
    .rst-content .wy-alert-warning.seealso,
    .rst-content .wy-alert-warning.tip,
    .wy-alert.wy-alert-warning {
        background-image: initial;
        /* Manually overridden */
        background-color: rgb(37, 33, 30);
        /*background-color: rgb(82, 53, 0);*/
    }
    .rst-content .admonition-todo .admonition-title,
    .rst-content .admonition-todo .wy-alert-title,
    .rst-content .attention .admonition-title,
    .rst-content .attention .wy-alert-title,
    .rst-content .caution .admonition-title,
    .rst-content .caution .wy-alert-title,
    .rst-content .warning .admonition-title,
    .rst-content .warning .wy-alert-title,
    .rst-content .wy-alert-warning.admonition .admonition-title,
    .rst-content .wy-alert-warning.admonition .wy-alert-title,
    .rst-content .wy-alert-warning.danger .admonition-title,
    .rst-content .wy-alert-warning.danger .wy-alert-title,
    .rst-content .wy-alert-warning.error .admonition-title,
    .rst-content .wy-alert-warning.error .wy-alert-title,
    .rst-content .wy-alert-warning.hint .admonition-title,
    .rst-content .wy-alert-warning.hint .wy-alert-title,
    .rst-content .wy-alert-warning.important .admonition-title,
    .rst-content .wy-alert-warning.important .wy-alert-title,
    .rst-content .wy-alert-warning.note .admonition-title,
    .rst-content .wy-alert-warning.note .wy-alert-title,
    .rst-content .wy-alert-warning.seealso .admonition-title,
    .rst-content .wy-alert-warning.seealso .wy-alert-title,
    .rst-content .wy-alert-warning.tip .admonition-title,
    .rst-content .wy-alert-warning.tip .wy-alert-title,
    .rst-content .wy-alert.wy-alert-warning .admonition-title,
    .wy-alert.wy-alert-warning .rst-content .admonition-title,
    .wy-alert.wy-alert-warning .wy-alert-title {
        background-image: initial;
        background-color: rgb(123, 65, 14);
    }
    .rst-content .note,
    .rst-content .seealso,
    .rst-content .wy-alert-info.admonition,
    .rst-content .wy-alert-info.admonition-todo,
    .rst-content .wy-alert-info.attention,
    .rst-content .wy-alert-info.caution,
    .rst-content .wy-alert-info.danger,
    .rst-content .wy-alert-info.error,
    .rst-content .wy-alert-info.hint,
    .rst-content .wy-alert-info.important,
    .rst-content .wy-alert-info.tip,
    .rst-content .wy-alert-info.warning,
    .wy-alert.wy-alert-info {
        background-image: initial;
        background-color: rgb(32, 35, 36);
    }
    .rst-content .note .admonition-title,
    .rst-content .note .wy-alert-title,
    .rst-content .seealso .admonition-title,
    .rst-content .seealso .wy-alert-title,
    .rst-content .wy-alert-info.admonition-todo .admonition-title,
    .rst-content .wy-alert-info.admonition-todo .wy-alert-title,
    .rst-content .wy-alert-info.admonition .admonition-title,
    .rst-content .wy-alert-info.admonition .wy-alert-title,
    .rst-content .wy-alert-info.attention .admonition-title,
    .rst-content .wy-alert-info.attention .wy-alert-title,
    .rst-content .wy-alert-info.caution .admonition-title,
    .rst-content .wy-alert-info.caution .wy-alert-title,
    .rst-content .wy-alert-info.danger .admonition-title,
    .rst-content .wy-alert-info.danger .wy-alert-title,
    .rst-content .wy-alert-info.error .admonition-title,
    .rst-content .wy-alert-info.error .wy-alert-title,
    .rst-content .wy-alert-info.hint .admonition-title,
    .rst-content .wy-alert-info.hint .wy-alert-title,
    .rst-content .wy-alert-info.important .admonition-title,
    .rst-content .wy-alert-info.important .wy-alert-title,
    .rst-content .wy-alert-info.tip .admonition-title,
    .rst-content .wy-alert-info.tip .wy-alert-title,
    .rst-content .wy-alert-info.warning .admonition-title,
    .rst-content .wy-alert-info.warning .wy-alert-title,
    .rst-content .wy-alert.wy-alert-info .admonition-title,
    .wy-alert.wy-alert-info .rst-content .admonition-title,
    .wy-alert.wy-alert-info .wy-alert-title {
        background-image: initial;
        background-color: rgb(29, 91, 131);
    }
    .rst-content .hint,
    .rst-content .important,
    .rst-content .tip,
    .rst-content .wy-alert-success.admonition,
    .rst-content .wy-alert-success.admonition-todo,
    .rst-content .wy-alert-success.attention,
    .rst-content .wy-alert-success.caution,
    .rst-content .wy-alert-success.danger,
    .rst-content .wy-alert-success.error,
    .rst-content .wy-alert-success.note,
    .rst-content .wy-alert-success.seealso,
    .rst-content .wy-alert-success.warning,
    .wy-alert.wy-alert-success {
        background-image: initial;
        background-color: rgb(9, 66, 58);
    }
    .rst-content .hint .admonition-title,
    .rst-content .hint .wy-alert-title,
    .rst-content .important .admonition-title,
    .rst-content .important .wy-alert-title,
    .rst-content .tip .admonition-title,
    .rst-content .tip .wy-alert-title,
    .rst-content .wy-alert-success.admonition-todo .admonition-title,
    .rst-content .wy-alert-success.admonition-todo .wy-alert-title,
    .rst-content .wy-alert-success.admonition .admonition-title,
    .rst-content .wy-alert-success.admonition .wy-alert-title,
    .rst-content .wy-alert-success.attention .admonition-title,
    .rst-content .wy-alert-success.attention .wy-alert-title,
    .rst-content .wy-alert-success.caution .admonition-title,
    .rst-content .wy-alert-success.caution .wy-alert-title,
    .rst-content .wy-alert-success.danger .admonition-title,
    .rst-content .wy-alert-success.danger .wy-alert-title,
    .rst-content .wy-alert-success.error .admonition-title,
    .rst-content .wy-alert-success.error .wy-alert-title,
    .rst-content .wy-alert-success.note .admonition-title,
    .rst-content .wy-alert-success.note .wy-alert-title,
    .rst-content .wy-alert-success.seealso .admonition-title,
    .rst-content .wy-alert-success.seealso .wy-alert-title,
    .rst-content .wy-alert-success.warning .admonition-title,
    .rst-content .wy-alert-success.warning .wy-alert-title,
    .rst-content .wy-alert.wy-alert-success .admonition-title,
    .wy-alert.wy-alert-success .rst-content .admonition-title,
    .wy-alert.wy-alert-success .wy-alert-title {
        background-image: initial;
        background-color: rgb(21, 150, 125);
    }
    .rst-content .wy-alert-neutral.admonition,
    .rst-content .wy-alert-neutral.admonition-todo,
    .rst-content .wy-alert-neutral.attention,
    .rst-content .wy-alert-neutral.caution,
    .rst-content .wy-alert-neutral.danger,
    .rst-content .wy-alert-neutral.error,
    .rst-content .wy-alert-neutral.hint,
    .rst-content .wy-alert-neutral.important,
    .rst-content .wy-alert-neutral.note,
    .rst-content .wy-alert-neutral.seealso,
    .rst-content .wy-alert-neutral.tip,
    .rst-content .wy-alert-neutral.warning,
    .wy-alert.wy-alert-neutral {
        background-image: initial;
        background-color: rgb(27, 36, 36);
    }
    .rst-content .wy-alert-neutral.admonition-todo .admonition-title,
    .rst-content .wy-alert-neutral.admonition-todo .wy-alert-title,
    .rst-content .wy-alert-neutral.admonition .admonition-title,
    .rst-content .wy-alert-neutral.admonition .wy-alert-title,
    .rst-content .wy-alert-neutral.attention .admonition-title,
    .rst-content .wy-alert-neutral.attention .wy-alert-title,
    .rst-content .wy-alert-neutral.caution .admonition-title,
    .rst-content .wy-alert-neutral.caution .wy-alert-title,
    .rst-content .wy-alert-neutral.danger .admonition-title,
    .rst-content .wy-alert-neutral.danger .wy-alert-title,
    .rst-content .wy-alert-neutral.error .admonition-title,
    .rst-content .wy-alert-neutral.error .wy-alert-title,
    .rst-content .wy-alert-neutral.hint .admonition-title,
    .rst-content .wy-alert-neutral.hint .wy-alert-title,
    .rst-content .wy-alert-neutral.important .admonition-title,
    .rst-content .wy-alert-neutral.important .wy-alert-title,
    .rst-content .wy-alert-neutral.note .admonition-title,
    .rst-content .wy-alert-neutral.note .wy-alert-title,
    .rst-content .wy-alert-neutral.seealso .admonition-title,
    .rst-content .wy-alert-neutral.seealso .wy-alert-title,
    .rst-content .wy-alert-neutral.tip .admonition-title,
    .rst-content .wy-alert-neutral.tip .wy-alert-title,
    .rst-content .wy-alert-neutral.warning .admonition-title,
    .rst-content .wy-alert-neutral.warning .wy-alert-title,
    .rst-content .wy-alert.wy-alert-neutral .admonition-title,
    .wy-alert.wy-alert-neutral .rst-content .admonition-title,
    .wy-alert.wy-alert-neutral .wy-alert-title {
        color: rgb(192, 186, 178);
        background-image: initial;
        background-color: rgb(40, 43, 45);
    }
    .rst-content .wy-alert-neutral.admonition-todo a,
    .rst-content .wy-alert-neutral.admonition a,
    .rst-content .wy-alert-neutral.attention a,
    .rst-content .wy-alert-neutral.caution a,
    .rst-content .wy-alert-neutral.danger a,
    .rst-content .wy-alert-neutral.error a,
    .rst-content .wy-alert-neutral.hint a,
    .rst-content .wy-alert-neutral.important a,
    .rst-content .wy-alert-neutral.note a,
    .rst-content .wy-alert-neutral.seealso a,
    .rst-content .wy-alert-neutral.tip a,
    .rst-content .wy-alert-neutral.warning a,
    .wy-alert.wy-alert-neutral a {
        color: rgb(84, 164, 217);
    }
    .wy-tray-container li {
        background-image: initial;
        background-color: transparent;
        color: rgb(232, 230, 227);
        box-shadow: rgba(0, 0, 0, 0.1) 0px 5px 5px 0px;
    }
    .wy-tray-container li.wy-tray-item-success {
        background-image: initial;
        background-color: rgb(31, 139, 77);
    }
    .wy-tray-container li.wy-tray-item-info {
        background-image: initial;
        background-color: rgb(33, 102, 148);
    }
    .wy-tray-container li.wy-tray-item-warning {
        background-image: initial;
        background-color: rgb(178, 94, 20);
    }
    .wy-tray-container li.wy-tray-item-danger {
        background-image: initial;
        background-color: rgb(162, 33, 20);
    }
    .btn {
        color: rgb(232, 230, 227);
        border-color: rgba(140, 130, 115, 0.1);
        background-color: rgb(31, 139, 77);
        text-decoration-color: initial;
        box-shadow: rgba(24, 26, 27, 0.5) 0px 1px 2px -1px inset,
        rgba(0, 0, 0, 0.1) 0px -2px 0px 0px inset;
    }
    .btn-hover {
        background-image: initial;
        background-color: rgb(37, 114, 165);
        color: rgb(232, 230, 227);
    }
    .btn:hover {
        background-image: initial;
        background-color: rgb(35, 156, 86);
        color: rgb(232, 230, 227);
    }
    .btn:focus {
        background-image: initial;
        background-color: rgb(35, 156, 86);
        outline-color: initial;
    }
    .btn:active {
        box-shadow: rgba(0, 0, 0, 0.05) 0px -1px 0px 0px inset,
        rgba(0, 0, 0, 0.1) 0px 2px 0px 0px inset;
    }
    .btn:visited {
        color: rgb(232, 230, 227);
    }
    .btn-disabled,
    .btn-disabled:active,
    .btn-disabled:focus,
    .btn-disabled:hover,
    .btn:disabled {
        background-image: none;
        box-shadow: none;
    }
    .btn-info {
        background-color: rgb(33, 102, 148) !important;
    }
    .btn-info:hover {
        background-color: rgb(37, 114, 165) !important;
    }
    .btn-neutral {
        background-color: rgb(27, 36, 36) !important;
        color: rgb(192, 186, 178) !important;
    }
    .btn-neutral:hover {
        color: rgb(192, 186, 178);
        background-color: rgb(34, 44, 44) !important;
    }
    .btn-neutral:visited {
        color: rgb(192, 186, 178) !important;
    }
    .btn-success {
        background-color: rgb(31, 139, 77) !important;
    }
    .btn-success:hover {
        background-color: rgb(27, 122, 68) !important;
    }
    .btn-danger {
        background-color: rgb(162, 33, 20) !important;
    }
    .btn-danger:hover {
        background-color: rgb(149, 30, 18) !important;
    }
    .btn-warning {
        background-color: rgb(178, 94, 20) !important;
    }
    .btn-warning:hover {
        background-color: rgb(165, 87, 18) !important;
    }
    .btn-invert {
        background-color: rgb(26, 28, 29);
    }
    .btn-invert:hover {
        background-color: rgb(35, 38, 40) !important;
    }
    .btn-link {
        color: rgb(84, 164, 217);
        box-shadow: none;
        background-color: transparent !important;
        border-color: transparent !important;
    }
    .btn-link:active,
    .btn-link:hover {
        box-shadow: none;
        background-color: transparent !important;
        color: rgb(79, 162, 216) !important;
    }
    .btn-link:visited {
        color: rgb(164, 103, 188);
    }
    .wy-dropdown-menu {
        background-image: initial;
        background-color: rgb(26, 28, 29);
        border-color: rgb(60, 65, 67);
        box-shadow: rgba(0, 0, 0, 0.1) 0px 2px 2px 0px;
    }
    .wy-dropdown-menu > dd > a {
        color: rgb(192, 186, 178);
    }
    .wy-dropdown-menu > dd > a:hover {
        background-image: initial;
        background-color: rgb(33, 102, 148);
        color: rgb(232, 230, 227);
    }
    .wy-dropdown-menu > dd.divider {
        border-top-color: rgb(60, 65, 67);
    }
    .wy-dropdown-menu > dd.call-to-action {
        background-image: initial;
        background-color: rgb(40, 43, 45);
    }
    .wy-dropdown-menu > dd.call-to-action:hover {
        background-image: initial;
        background-color: rgb(40, 43, 45);
    }
    .wy-dropdown-menu > dd.call-to-action .btn {
        color: rgb(232, 230, 227);
    }
    .wy-dropdown.wy-dropdown-bubble .wy-dropdown-menu {
        background-image: initial;
        background-color: rgb(26, 28, 29);
    }
    .wy-dropdown.wy-dropdown-bubble .wy-dropdown-menu a:hover {
        background-image: initial;
        background-color: rgb(33, 102, 148);
        color: rgb(232, 230, 227);
    }
    .wy-dropdown-arrow::before {
        border-bottom-color: rgb(51, 55, 57);
        border-left-color: transparent;
        border-right-color: transparent;
    }
    fieldset,
    legend {
        border-color: initial;
    }
    label {
        color: rgb(200, 195, 188);
    }
    .wy-control-group.wy-control-group-required > label::after {
        color: rgb(233, 88, 73);
    }
    .wy-form-message-inline {
        color: rgb(168, 160, 149);
    }
    .wy-form-message {
        color: rgb(168, 160, 149);
    }
    input[type="color"], input[type="date"], input[type="datetime-local"], input[type="datetime"], input[type="email"], input[type="month"], input[type="number"], input[type="password"], input[type="search"], input[type="tel"], input[type="text"], input[type="time"], input[type="url"], input[type="week"] {
        border-color: rgb(62, 68, 70);
        box-shadow: rgb(43, 47, 49) 0px 1px 3px inset;
    }
    input[type="color"]:focus, input[type="date"]:focus, input[type="datetime-local"]:focus, input[type="datetime"]:focus, input[type="email"]:focus, input[type="month"]:focus, input[type="number"]:focus, input[type="password"]:focus, input[type="search"]:focus, input[type="tel"]:focus, input[type="text"]:focus, input[type="time"]:focus, input[type="url"]:focus, input[type="week"]:focus {
        outline-color: initial;
        border-color: rgb(123, 114, 101);
    }
    input.no-focus:focus {
        border-color: rgb(62, 68, 70) !important;
    }
    input[type="checkbox"]:focus, input[type="file"]:focus, input[type="radio"]:focus {
        outline-color: rgb(13, 113, 167);
    }
    input[type="color"][disabled], input[type="date"][disabled], input[type="datetime-local"][disabled], input[type="datetime"][disabled], input[type="email"][disabled], input[type="month"][disabled], input[type="number"][disabled], input[type="password"][disabled], input[type="search"][disabled], input[type="tel"][disabled], input[type="text"][disabled], input[type="time"][disabled], input[type="url"][disabled], input[type="week"][disabled] {
        background-color: rgb(27, 29, 30);
    }
    input:focus:invalid,
    select:focus:invalid,
    textarea:focus:invalid {
        color: rgb(233, 88, 73);
        border-color: rgb(149, 31, 18);
    }
    input:focus:invalid:focus,
    select:focus:invalid:focus,
    textarea:focus:invalid:focus {
        border-color: rgb(149, 31, 18);
    }
    input[type="checkbox"]:focus:invalid:focus, input[type="file"]:focus:invalid:focus, input[type="radio"]:focus:invalid:focus {
        outline-color: rgb(149, 31, 18);
    }
    select,
    textarea {
        border-color: rgb(62, 68, 70);
        box-shadow: rgb(43, 47, 49) 0px 1px 3px inset;
    }
    select {
        border-color: rgb(62, 68, 70);
        background-color: rgb(24, 26, 27);
    }
    select:focus,
    textarea:focus {
        outline-color: initial;
    }
    input[readonly],
    select[disabled],
    select[readonly],
    textarea[disabled],
    textarea[readonly] {
        background-color: rgb(27, 29, 30);
    }
    .wy-checkbox,
    .wy-radio {
        color: rgb(192, 186, 178);
    }
    .wy-input-prefix .wy-input-context,
    .wy-input-suffix .wy-input-context {
        background-color: rgb(27, 36, 36);
        border-color: rgb(62, 68, 70);
        color: rgb(168, 160, 149);
    }
    .wy-input-suffix .wy-input-context {
        border-left-color: initial;
    }
    .wy-input-prefix .wy-input-context {
        border-right-color: initial;
    }
    .wy-switch::before {
        background-image: initial;
        background-color: rgb(53, 57, 59);
    }
    .wy-switch::after {
        background-image: initial;
        background-color: rgb(82, 88, 92);
    }
    .wy-switch span {
        color: rgb(200, 195, 188);
    }
    .wy-switch.active::before {
        background-image: initial;
        background-color: rgb(24, 106, 58);
    }
    .wy-switch.active::after {
        background-image: initial;
        background-color: rgb(31, 139, 77);
    }
    .wy-control-group.wy-control-group-error .wy-form-message,
    .wy-control-group.wy-control-group-error > label {
        color: rgb(233, 88, 73);
    }
    .wy-control-group.wy-control-group-error input[type="color"], .wy-control-group.wy-control-group-error input[type="date"], .wy-control-group.wy-control-group-error input[type="datetime-local"], .wy-control-group.wy-control-group-error input[type="datetime"], .wy-control-group.wy-control-group-error input[type="email"], .wy-control-group.wy-control-group-error input[type="month"], .wy-control-group.wy-control-group-error input[type="number"], .wy-control-group.wy-control-group-error input[type="password"], .wy-control-group.wy-control-group-error input[type="search"], .wy-control-group.wy-control-group-error input[type="tel"], .wy-control-group.wy-control-group-error input[type="text"], .wy-control-group.wy-control-group-error input[type="time"], .wy-control-group.wy-control-group-error input[type="url"], .wy-control-group.wy-control-group-error input[type="week"],
    .wy-control-group.wy-control-group-error textarea {
        border-color: rgb(149, 31, 18);
    }
    .wy-inline-validate.wy-inline-validate-success .wy-input-context {
        color: rgb(92, 218, 145);
    }
    .wy-inline-validate.wy-inline-validate-danger .wy-input-context {
        color: rgb(233, 88, 73);
    }
    .wy-inline-validate.wy-inline-validate-warning .wy-input-context {
        color: rgb(232, 138, 54);
    }
    .wy-inline-validate.wy-inline-validate-info .wy-input-context {
        color: rgb(84, 164, 217);
    }
    .rst-content table.docutils caption,
    .rst-content table.field-list caption,
    .wy-table caption {
        color: rgb(232, 230, 227);
    }
    .rst-content table.docutils thead,
    .rst-content table.field-list thead,
    .wy-table thead {
        color: rgb(232, 230, 227);
    }
    .rst-content table.docutils thead th,
    .rst-content table.field-list thead th,
    .wy-table thead th {
        border-bottom-color: rgb(56, 61, 63);
    }
    .rst-content table.docutils td,
    .rst-content table.field-list td,
    .wy-table td {
        background-color: transparent;
    }
    .wy-table-secondary {
        color: rgb(152, 143, 129);
    }
    .wy-table-tertiary {
        color: rgb(152, 143, 129);
    }
    .rst-content table.docutils:not(.field-list) tr:nth-child(2n-1) td,
    .wy-table-backed,
    .wy-table-odd td,
    .wy-table-striped tr:nth-child(2n-1) td {
        background-color: rgb(27, 36, 36);
    }
    .rst-content table.docutils,
    .wy-table-bordered-all {
        border-color: rgb(56, 61, 63);
    }
    .rst-content table.docutils td,
    .wy-table-bordered-all td {
        border-bottom-color: rgb(56, 61, 63);
        border-left-color: rgb(56, 61, 63);
    }
    .wy-table-bordered {
        border-color: rgb(56, 61, 63);
    }
    .wy-table-bordered-rows td {
        border-bottom-color: rgb(56, 61, 63);
    }
    .wy-table-horizontal td,
    .wy-table-horizontal th {
        border-bottom-color: rgb(56, 61, 63);
    }
    a {
        color: rgb(84, 164, 217);
        text-decoration-color: initial;
    }
    a:hover {
        color: rgb(68, 156, 214);
    }
    a:visited {
        color: rgb(164, 103, 188);
    }
    body {
        color: rgb(192, 186, 178);
        background-image: initial;
        background-color: rgb(33, 35, 37);
    }
    .wy-text-strike {
        text-decoration-color: initial;
    }
    .wy-text-warning {
        color: rgb(232, 138, 54) !important;
    }
    a.wy-text-warning:hover {
        color: rgb(236, 157, 87) !important;
    }
    .wy-text-info {
        color: rgb(84, 164, 217) !important;
    }
    a.wy-text-info:hover {
        color: rgb(79, 162, 216) !important;
    }
    .wy-text-success {
        color: rgb(92, 218, 145) !important;
    }
    a.wy-text-success:hover {
        color: rgb(73, 214, 133) !important;
    }
    .wy-text-danger {
        color: rgb(233, 88, 73) !important;
    }
    a.wy-text-danger:hover {
        color: rgb(237, 118, 104) !important;
    }
    .wy-text-neutral {
        color: rgb(192, 186, 178) !important;
    }
    a.wy-text-neutral:hover {
        color: rgb(176, 169, 159) !important;
    }
    hr {
        border-right-color: initial;
        border-bottom-color: initial;
        border-left-color: initial;
        border-top-color: rgb(56, 61, 63);
    }
    .rst-content code,
    .rst-content tt,
    code {
        background-image: initial;
        background-color: rgb(24, 26, 27);
        border-color: rgb(56, 61, 63);
        color: rgb(233, 88, 73);
    }
    .rst-content .section ul,
    .rst-content .toctree-wrapper ul,
    .wy-plain-list-disc,
    article ul {
        list-style-image: initial;
    }
    .rst-content .section ul li,
    .rst-content .toctree-wrapper ul li,
    .wy-plain-list-disc li,
    article ul li {
        list-style-image: initial;
    }
    .rst-content .section ul li li,
    .rst-content .toctree-wrapper ul li li,
    .wy-plain-list-disc li li,
    article ul li li {
        list-style-image: initial;
    }
    .rst-content .section ul li li li,
    .rst-content .toctree-wrapper ul li li li,
    .wy-plain-list-disc li li li,
    article ul li li li {
        list-style-image: initial;
    }
    .rst-content .section ul li ol li,
    .rst-content .toctree-wrapper ul li ol li,
    .wy-plain-list-disc li ol li,
    article ul li ol li {
        list-style-image: initial;
    }
    .rst-content .section ol,
    .rst-content ol.arabic,
    .wy-plain-list-decimal,
    article ol {
        list-style-image: initial;
    }
    .rst-content .section ol li,
    .rst-content ol.arabic li,
    .wy-plain-list-decimal li,
    article ol li {
        list-style-image: initial;
    }
    .rst-content .section ol li ul li,
    .rst-content ol.arabic li ul li,
    .wy-plain-list-decimal li ul li,
    article ol li ul li {
        list-style-image: initial;
    }
    .rst-content .wy-breadcrumbs li tt,
    .wy-breadcrumbs li .rst-content tt,
    .wy-breadcrumbs li code {
        border-color: initial;
        background-image: none;
        background-color: initial;
    }
    .rst-content .wy-breadcrumbs li tt.literal,
    .wy-breadcrumbs li .rst-content tt.literal,
    .wy-breadcrumbs li code.literal {
        color: rgb(192, 186, 178);
    }
    .wy-breadcrumbs-extra {
        color: rgb(184, 178, 169);
    }
    .wy-menu a:hover {
        text-decoration-color: initial;
    }
    .wy-menu-horiz li:hover {
        background-image: initial;
        background-color: rgba(24, 26, 27, 0.1);
    }
    .wy-menu-horiz li.divide-left {
        border-left-color: rgb(119, 110, 98);
    }
    .wy-menu-horiz li.divide-right {
        border-right-color: rgb(119, 110, 98);
    }
    .wy-menu-vertical header,
    .wy-menu-vertical p.caption {
        color: rgb(94, 170, 219);
    }
    .wy-menu-vertical li.divide-top {
        border-top-color: rgb(119, 110, 98);
    }
    .wy-menu-vertical li.divide-bottom {
        border-bottom-color: rgb(119, 110, 98);
    }
    .wy-menu-vertical li.current {
        background-image: initial;
        background-color: rgb(40, 43, 45);
    }
    .wy-menu-vertical li.current a {
        color: rgb(152, 143, 129);
        border-right-color: rgb(63, 69, 71);
    }
    .wy-menu-vertical li.current a:hover {
        background-image: initial;
        background-color: rgb(47, 51, 53);
    }
    .rst-content .wy-menu-vertical li tt,
    .wy-menu-vertical li .rst-content tt,
    .wy-menu-vertical li code {
        border-color: initial;
        background-image: inherit;
        background-color: inherit;
        color: inherit;
    }
    .wy-menu-vertical li span.toctree-expand {
        color: rgb(183, 177, 168);
    }
    .wy-menu-vertical li.current > a,
    .wy-menu-vertical li.on a {
        color: rgb(192, 186, 178);
        background-image: initial;
        background-color: rgb(26, 28, 29);
        border-color: initial;
    }
    .wy-menu-vertical li.current > a:hover,
    .wy-menu-vertical li.on a:hover {
        background-image: initial;
        background-color: rgb(26, 28, 29);
    }
    .wy-menu-vertical li.current > a:hover span.toctree-expand,
    .wy-menu-vertical li.on a:hover span.toctree-expand {
        color: rgb(152, 143, 129);
    }
    .wy-menu-vertical li.current > a span.toctree-expand,
    .wy-menu-vertical li.on a span.toctree-expand {
        color: rgb(200, 195, 188);
    }
    .wy-menu-vertical li.toctree-l1.current > a {
        border-bottom-color: rgb(63, 69, 71);
        border-top-color: rgb(63, 69, 71);
    }
    .wy-menu-vertical li.toctree-l2 a,
    .wy-menu-vertical li.toctree-l3 a,
    .wy-menu-vertical li.toctree-l4 a,
    .wy-menu-vertical li.toctree-l5 a,
    .wy-menu-vertical li.toctree-l6 a,
    .wy-menu-vertical li.toctree-l7 a,
    .wy-menu-vertical li.toctree-l8 a,
    .wy-menu-vertical li.toctree-l9 a,
    .wy-menu-vertical li.toctree-l10 a {
        color: rgb(192, 186, 178);
    }
    .wy-menu-vertical li.toctree-l2 a:hover span.toctree-expand,
    .wy-menu-vertical li.toctree-l3 a:hover span.toctree-expand,
    .wy-menu-vertical li.toctree-l4 a:hover span.toctree-expand,
    .wy-menu-vertical li.toctree-l5 a:hover span.toctree-expand,
    .wy-menu-vertical li.toctree-l6 a:hover span.toctree-expand,
    .wy-menu-vertical li.toctree-l7 a:hover span.toctree-expand,
    .wy-menu-vertical li.toctree-l8 a:hover span.toctree-expand,
    .wy-menu-vertical li.toctree-l9 a:hover span.toctree-expand,
    .wy-menu-vertical li.toctree-l10 a:hover span.toctree-expand {
        color: rgb(152, 143, 129);
    }
    .wy-menu-vertical li.toctree-l2.current > a,
    .wy-menu-vertical li.toctree-l2.current li.toctree-l3 > a {
        background-image: initial;
        background-color: rgb(54, 59, 61);
    }
    .wy-menu-vertical li.toctree-l2 span.toctree-expand {
        color: rgb(174, 167, 156);
    }
    .wy-menu-vertical li.toctree-l3.current > a,
    .wy-menu-vertical li.toctree-l3.current li.toctree-l4 > a {
        background-image: initial;
        background-color: rgb(61, 66, 69);
    }
    .wy-menu-vertical li.toctree-l3 span.toctree-expand {
        color: rgb(166, 158, 146);
    }
    .wy-menu-vertical li ul li a {
        color: rgb(208, 204, 198);
    }
    .wy-menu-vertical a {
        color: rgb(208, 204, 198);
    }
    .wy-menu-vertical a:hover {
        background-color: rgb(57, 62, 64);
    }
    .wy-menu-vertical a:hover span.toctree-expand {
        color: rgb(208, 204, 198);
    }
    .wy-menu-vertical a:active {
        background-color: rgb(33, 102, 148);
        color: rgb(232, 230, 227);
    }
    .wy-menu-vertical a:active span.toctree-expand {
        color: rgb(232, 230, 227);
    }
    .wy-side-nav-search {
        background-color: rgb(33, 102, 148);
        color: rgb(230, 228, 225);
    }
    .wy-side-nav-search input[type="text"] {
        border-color: rgb(35, 111, 160);
    }
    .wy-side-nav-search img {
        background-color: rgb(33, 102, 148);
    }
    .wy-side-nav-search .wy-dropdown > a,
    .wy-side-nav-search > a {
        color: rgb(230, 228, 225);
    }
    .wy-side-nav-search .wy-dropdown > a:hover,
    .wy-side-nav-search > a:hover {
        background-image: initial;
        background-color: rgba(24, 26, 27, 0.1);
    }
    .wy-side-nav-search .wy-dropdown > a img.logo,
    .wy-side-nav-search > a img.logo {
        background-image: initial;
        background-color: transparent;
    }
    .wy-side-nav-search > div.version {
        color: rgba(232, 230, 227, 0.3);
    }
    .wy-nav .wy-menu-vertical header {
        color: rgb(84, 164, 217);
    }
    .wy-nav .wy-menu-vertical a {
        color: rgb(184, 178, 169);
    }
    .wy-nav .wy-menu-vertical a:hover {
        background-color: rgb(33, 102, 148);
        color: rgb(232, 230, 227);
    }
    .wy-body-for-nav {
        background-image: initial;
        background-color: rgb(26, 28, 29);
    }
    .wy-nav-side {
        color: rgb(169, 161, 150);
        background-image: initial;
        background-color: rgb(38, 41, 43);
    }
    .wy-nav-top {
        background-image: initial;
        background-color: rgb(33, 102, 148);
        color: rgb(232, 230, 227);
    }
    .wy-nav-top a {
        color: rgb(232, 230, 227);
    }
    .wy-nav-top img {
        background-color: rgb(33, 102, 148);
    }
    .wy-nav-content-wrap {
        background-image: initial;
        background-color: rgb(26, 28, 29);
    }
    .wy-body-mask {
        background-image: initial;
        background-color: rgba(0, 0, 0, 0.2);
    }
    footer {
        color: rgb(152, 143, 129);
    }
    .rst-content footer span.commit tt,
    footer span.commit .rst-content tt,
    footer span.commit code {
        background-image: none;
        background-color: initial;
        border-color: initial;
        color: rgb(152, 143, 129);
    }
    #search-results .search li {
        border-bottom-color: rgb(56, 61, 63);
    }
    #search-results .search li:first-child {
        border-top-color: rgb(56, 61, 63);
    }
    #search-results .context {
        color: rgb(152, 143, 129);
    }
    .wy-body-for-nav {
        background-image: initial;
        background-color: rgb(26, 28, 29);
    }
    @media screen and (min-width: 1100px) {
        .wy-nav-content-wrap {
            background-image: initial;
            background-color: rgba(0, 0, 0, 0.05);
        }
        .wy-nav-content {
            background-image: initial;
            background-color: rgb(26, 28, 29);
        }
    }
    .rst-versions {
        color: rgb(230, 228, 225);
        background-image: initial;
        background-color: rgb(23, 24, 25);
    }
    .rst-versions a {
        color: rgb(84, 164, 217);
        text-decoration-color: initial;
    }
    .rst-versions .rst-current-version {
        background-color: rgb(29, 31, 32);
        color: rgb(92, 218, 145);
    }
    .rst-content .code-block-caption .rst-versions .rst-current-version .headerlink,
    .rst-content .rst-versions .rst-current-version .admonition-title,
    .rst-content code.download .rst-versions .rst-current-version span:first-child,
    .rst-content dl dt .rst-versions .rst-current-version .headerlink,
    .rst-content h1 .rst-versions .rst-current-version .headerlink,
    .rst-content h2 .rst-versions .rst-current-version .headerlink,
    .rst-content h3 .rst-versions .rst-current-version .headerlink,
    .rst-content h4 .rst-versions .rst-current-version .headerlink,
    .rst-content h5 .rst-versions .rst-current-version .headerlink,
    .rst-content h6 .rst-versions .rst-current-version .headerlink,
    .rst-content p.caption .rst-versions .rst-current-version .headerlink,
    .rst-content table > caption .rst-versions .rst-current-version .headerlink,
    .rst-content tt.download .rst-versions .rst-current-version span:first-child,
    .rst-versions .rst-current-version .fa,
    .rst-versions .rst-current-version .icon,
    .rst-versions .rst-current-version .rst-content .admonition-title,
    .rst-versions .rst-current-version .rst-content .code-block-caption .headerlink,
    .rst-versions .rst-current-version .rst-content code.download span:first-child,
    .rst-versions .rst-current-version .rst-content dl dt .headerlink,
    .rst-versions .rst-current-version .rst-content h1 .headerlink,
    .rst-versions .rst-current-version .rst-content h2 .headerlink,
    .rst-versions .rst-current-version .rst-content h3 .headerlink,
    .rst-versions .rst-current-version .rst-content h4 .headerlink,
    .rst-versions .rst-current-version .rst-content h5 .headerlink,
    .rst-versions .rst-current-version .rst-content h6 .headerlink,
    .rst-versions .rst-current-version .rst-content p.caption .headerlink,
    .rst-versions .rst-current-version .rst-content table > caption .headerlink,
    .rst-versions .rst-current-version .rst-content tt.download span:first-child,
    .rst-versions .rst-current-version .wy-menu-vertical li span.toctree-expand,
    .wy-menu-vertical li .rst-versions .rst-current-version span.toctree-expand {
        color: rgb(230, 228, 225);
    }
    .rst-versions .rst-current-version.rst-out-of-date {
        background-color: rgb(162, 33, 20);
        color: rgb(232, 230, 227);
    }
    .rst-versions .rst-current-version.rst-active-old-version {
        background-color: rgb(192, 156, 11);
        color: rgb(232, 230, 227);
    }
    .rst-versions .rst-other-versions {
        color: rgb(152, 143, 129);
    }
    .rst-versions .rst-other-versions hr {
        border-right-color: initial;
        border-bottom-color: initial;
        border-left-color: initial;
        border-top-color: rgb(119, 111, 98);
    }
    .rst-versions .rst-other-versions dd a {
        color: rgb(230, 228, 225);
    }
    .rst-versions.rst-badge {
        border-color: initial;
    }
    .rst-content abbr[title] {
        text-decoration-color: initial;
    }
    .rst-content.style-external-links a.reference.external::after {
        color: rgb(184, 178, 169);
    }
    .rst-content div[class^="highlight"],
    .rst-content pre.literal-block {
        border-color: rgb(56, 61, 63);
    }
    .rst-content div[class^="highlight"] div[class^="highlight"], .rst-content pre.literal-block div[class^="highlight"] {
        border-color: initial;
    }
    .rst-content .linenodiv pre {
        border-right-color: rgb(54, 59, 61);
    }
    .rst-content .admonition table {
        border-color: rgba(140, 130, 115, 0.1);
    }
    .rst-content .admonition table td,
    .rst-content .admonition table th {
        background-image: initial !important;
        background-color: transparent !important;
        border-color: rgba(140, 130, 115, 0.1) !important;
    }
    .rst-content .section ol.loweralpha,
    .rst-content .section ol.loweralpha > li {
        list-style-image: initial;
    }
    .rst-content .section ol.upperalpha,
    .rst-content .section ol.upperalpha > li {
        list-style-image: initial;
    }
    .rst-content .toc-backref {
        color: rgb(192, 186, 178);
    }
    .rst-content .sidebar {
        background-image: initial;
        background-color: rgb(27, 36, 36);
        border-color: rgb(56, 61, 63);
    }
    .rst-content .sidebar .sidebar-title {
        background-image: initial;
        background-color: rgb(40, 43, 45);
    }
    .rst-content .highlighted {
        background-image: initial;
        background-color: rgb(192, 156, 11);
        box-shadow: rgb(192, 156, 11) 0px 0px 0px 2px;
    }
    html.writer-html4 .rst-content table.docutils.citation,
    html.writer-html4 .rst-content table.docutils.footnote {
        background-image: none;
        background-color: initial;
        border-color: initial;
    }
    html.writer-html4 .rst-content table.docutils.citation td,
    html.writer-html4 .rst-content table.docutils.citation tr,
    html.writer-html4 .rst-content table.docutils.footnote td,
    html.writer-html4 .rst-content table.docutils.footnote tr {
        border-color: initial;
        background-color: transparent !important;
    }
    .rst-content table.docutils.footnote,
    html.writer-html4 .rst-content table.docutils.citation,
    html.writer-html5 .rst-content dl.footnote {
        color: rgb(152, 143, 129);
    }
    .rst-content table.docutils.footnote code,
    .rst-content table.docutils.footnote tt,
    html.writer-html4 .rst-content table.docutils.citation code,
    html.writer-html4 .rst-content table.docutils.citation tt,
    html.writer-html5 .rst-content dl.footnote code,
    html.writer-html5 .rst-content dl.footnote tt {
        color: rgb(178, 172, 162);
    }
    .rst-content table.docutils th {
        border-color: rgb(56, 61, 63);
    }
    html.writer-html5 .rst-content table.docutils th {
        border-color: rgb(56, 61, 63);
    }
    .rst-content table.field-list,
    .rst-content table.field-list td {
        border-color: initial;
    }
    .rst-content code,
    .rst-content tt {
        color: rgb(232, 230, 227);
    }
    .rst-content code.literal,
    .rst-content tt.literal {
        /* Manually overridden */
        color: rgb(228, 138, 128);
        /*color: rgb(233, 88, 73);*/
    }
    .rst-content code.xref,
    .rst-content tt.xref,
    a .rst-content code,
    a .rst-content tt {
        color: rgb(192, 186, 178);
    }
    .rst-content a code,
    .rst-content a tt {
        color: rgb(84, 164, 217);
    }
    html.writer-html4 .rst-content dl:not(.docutils) > dt,
    html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) > dt {
        background-image: initial;
        background-color: rgb(32, 35, 36);
        color: rgb(84, 164, 217);
        border-top-color: rgb(28, 89, 128);
    }
    html.writer-html4 .rst-content dl:not(.docutils) > dt::before,
    html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) > dt::before {
        color: rgb(109, 178, 223);
    }
    html.writer-html4 .rst-content dl:not(.docutils) > dt .headerlink,
    html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) > dt .headerlink {
        color: rgb(192, 186, 178);
    }
    html.writer-html4 .rst-content dl:not(.docutils) dl:not(.field-list) > dt,
    html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) dl:not(.field-list) > dt {
        border-top-color: initial;
        border-right-color: initial;
        border-bottom-color: initial;
        border-left-color: rgb(62, 68, 70);
        background-image: initial;
        background-color: rgb(32, 35, 37);
        color: rgb(178, 172, 162);
    }
    html.writer-html4 .rst-content dl:not(.docutils) dl:not(.field-list) > dt .headerlink,
    html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) dl:not(.field-list) > dt .headerlink {
        color: rgb(192, 186, 178);
    }
    html.writer-html4 .rst-content dl:not(.docutils) code.descclassname,
    html.writer-html4 .rst-content dl:not(.docutils) code.descname,
    html.writer-html4 .rst-content dl:not(.docutils) tt.descclassname,
    html.writer-html4 .rst-content dl:not(.docutils) tt.descname,
    html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) code.descclassname,
    html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) code.descname,
    html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) tt.descclassname,
    html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) tt.descname {
        background-color: transparent;
        border-color: initial;
    }
    html.writer-html4 .rst-content dl:not(.docutils) .optional,
    html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) .optional {
        color: rgb(232, 230, 227);
    }
    .rst-content .viewcode-back,
    .rst-content .viewcode-link {
        color: rgb(92, 218, 145);
    }
    .rst-content code.download,
    .rst-content tt.download {
        background-image: inherit;
        background-color: inherit;
        color: inherit;
        border-color: inherit;
    }
    .rst-content .guilabel {
        border-color: rgb(27, 84, 122);
        background-image: initial;
        background-color: rgb(32, 35, 36);
    }
    span[id*="MathJax-Span"] {
        color: rgb(192, 186, 178);
    }
    td.linenos pre {
        color: rgb(232, 230, 227);
        background-color: rgb(32, 35, 37);
    }
    span.linenos {
        color: rgb(232, 230, 227);
        background-color: rgb(32, 35, 37);
    }
    td.linenos pre.special {
        color: rgb(232, 230, 227);
        background-color: rgb(89, 89, 0);
    }
    span.linenos.special {
        color: rgb(232, 230, 227);
        background-color: rgb(89, 89, 0);
    }
    .highlight .hll {
        background-color: rgb(82, 82, 0);
    }
    .highlight {
        background-image: initial;
        /* Manually overridden */
        background-color: rgb(44 47 37);
        /*background-color: rgb(61, 82, 0);*/
    }
    .highlight .c {
        color: rgb(119, 179, 195);
    }
    .highlight .err {
        border-color: rgb(179, 0, 0);
    }
    .highlight .k {
        color: rgb(126, 255, 163);
    }
    .highlight .o {
        color: rgb(168, 160, 149);
    }
    .highlight .ch {
        color: rgb(119, 179, 195);
    }
    .highlight .cm {
        color: rgb(119, 179, 195);
    }
    .highlight .cp {
        color: rgb(126, 255, 163);
    }
    .highlight .cpf {
        color: rgb(119, 179, 195);
    }
    .highlight .c1 {
        color: rgb(119, 179, 195);
    }
    .highlight .cs {
        color: rgb(119, 179, 195);
        background-color: rgb(60, 0, 0);
    }
    .highlight .gd {
        color: rgb(255, 92, 92);
    }
    .highlight .gr {
        color: rgb(255, 26, 26);
    }
    .highlight .gh {
        color: rgb(127, 174, 255);
    }
    .highlight .gi {
        color: rgb(92, 255, 92);
    }
    .highlight .go {
        color: rgb(200, 195, 188);
    }
    .highlight .gp {
        color: rgb(246, 147, 68);
    }
    .highlight .gu {
        color: rgb(255, 114, 255);
    }
    .highlight .gt {
        color: rgb(71, 160, 255);
    }
    .highlight .kc {
        color: rgb(126, 255, 163);
    }
    .highlight .kd {
        color: rgb(126, 255, 163);
    }
    .highlight .kn {
        color: rgb(126, 255, 163);
    }
    .highlight .kp {
        color: rgb(126, 255, 163);
    }
    .highlight .kr {
        color: rgb(126, 255, 163);
    }
    .highlight .kt {
        color: rgb(255, 137, 103);
    }
    .highlight .m {
        color: rgb(125, 222, 174);
    }
    .highlight .s {
        color: rgb(123, 166, 202);
    }
    .highlight .na {
        color: rgb(123, 166, 202);
    }
    .highlight .nb {
        color: rgb(126, 255, 163);
    }
    .highlight .nc {
        color: rgb(81, 194, 242);
    }
    .highlight .no {
        color: rgb(103, 177, 215);
    }
    .highlight .nd {
        color: rgb(178, 172, 162);
    }
    .highlight .ni {
        color: rgb(217, 100, 73);
    }
    .highlight .ne {
        color: rgb(126, 255, 163);
    }
    .highlight .nf {
        color: rgb(131, 186, 249);
    }
    .highlight .nl {
        color: rgb(137, 193, 255);
    }
    .highlight .nn {
        color: rgb(81, 194, 242);
    }
    .highlight .nt {
        color: rgb(138, 191, 249);
    }
    .highlight .nv {
        color: rgb(190, 103, 215);
    }
    .highlight .ow {
        color: rgb(126, 255, 163);
    }
    .highlight .w {
        color: rgb(189, 183, 175);
    }
    .highlight .mb {
        color: rgb(125, 222, 174);
    }
    .highlight .mf {
        color: rgb(125, 222, 174);
    }
    .highlight .mh {
        color: rgb(125, 222, 174);
    }
    .highlight .mi {
        color: rgb(125, 222, 174);
    }
    .highlight .mo {
        color: rgb(125, 222, 174);
    }
    .highlight .sa {
        color: rgb(123, 166, 202);
    }
    .highlight .sb {
        color: rgb(123, 166, 202);
    }
    .highlight .sc {
        color: rgb(123, 166, 202);
    }
    .highlight .dl {
        color: rgb(123, 166, 202);
    }
    .highlight .sd {
        color: rgb(123, 166, 202);
    }
    .highlight .s2 {
        color: rgb(123, 166, 202);
    }
    .highlight .se {
        color: rgb(123, 166, 202);
    }
    .highlight .sh {
        color: rgb(123, 166, 202);
    }
    .highlight .si {
        color: rgb(117, 168, 209);
    }
    .highlight .sx {
        color: rgb(246, 147, 68);
    }
    .highlight .sr {
        color: rgb(133, 182, 224);
    }
    .highlight .s1 {
        color: rgb(123, 166, 202);
    }
    .highlight .ss {
        color: rgb(188, 230, 128);
    }
    .highlight .bp {
        color: rgb(126, 255, 163);
    }
    .highlight .fm {
        color: rgb(131, 186, 249);
    }
    .highlight .vc {
        color: rgb(190, 103, 215);
    }
    .highlight .vg {
        color: rgb(190, 103, 215);
    }
    .highlight .vi {
        color: rgb(190, 103, 215);
    }
    .highlight .vm {
        color: rgb(190, 103, 215);
    }
    .highlight .il {
        color: rgb(125, 222, 174);
    }
    @media (prefers-color-scheme: dark) {
        html {
            background-color: rgb(19, 21, 22) !important;
        }
        html,
        body,
        input,
        textarea,
        select,
        button {
            background-color: rgb(19, 21, 22);
        }
        html,
        body,
        input,
        textarea,
        select,
        button {
            border-color: rgb(106, 98, 87);
            color: rgb(216, 212, 207);
        }
        a {
            color: rgb(61, 165, 255);
        }
        table {
            border-color: rgb(111, 103, 91);
        }
        ::placeholder {
            color: rgb(178, 171, 161);
        }
        input:-webkit-autofill,
        textarea:-webkit-autofill,
        select:-webkit-autofill {
            background-color: rgb(68, 73, 0) !important;
            color: rgb(216, 212, 207) !important;
        }
        ::-webkit-scrollbar {
            background-color: rgb(26, 28, 29);
            color: rgb(173, 166, 156);
        }
        ::-webkit-scrollbar-thumb {
            background-color: rgb(55, 60, 62);
        }
        ::-webkit-scrollbar-thumb:hover {
            background-color: rgb(70, 75, 78);
        }
        ::-webkit-scrollbar-thumb:active {
            background-color: rgb(58, 62, 65);
        }
        ::-webkit-scrollbar-corner {
            background-color: rgb(19, 21, 22);
        }
        ::selection {
            background-color: rgb(0, 62, 136) !important;
            color: rgb(216, 212, 207) !important;
        }
        :root {
            --darkreader-neutral-background: #131516;
            --darkreader-text--darkreader-neutral-text: #cdc8c2;
            --darkreader-selection-background: #004daa;
            --darkreader-selection-text: #e8e6e3;
        }
        a:active,
        a:hover {
            outline-color: currentcolor;
        }
        abbr[title] {
            border-bottom-color: currentcolor;
        }
        ins {
            background-color: rgb(90, 90, 0);
            background-image: none;
            text-decoration-color: currentcolor;
        }
        ins,
        mark {
            color: rgb(216, 212, 207);
        }
        mark {
            background-color: rgb(163, 163, 0);
            background-image: none;
        }
        dl,
        ol,
        ul {
            list-style-image: none;
        }
        li {
            list-style-image: none;
        }
        img {
            border-color: currentcolor;
        }
        .chromeframe {
            background-color: rgb(42, 46, 47);
            background-image: none;
            color: rgb(216, 212, 207);
        }
        .ir {
            border-color: currentcolor;
            background-color: transparent;
        }
        .visuallyhidden {
            border-color: currentcolor;
        }
        .fa-border {
            border-color: rgb(122, 113, 100);
        }
        .fa-inverse {
            color: rgb(216, 212, 207);
        }
        .sr-only {
            border-color: currentcolor;
        }
        .fa::before,
        .icon::before,
        .rst-content .admonition-title::before,
        .rst-content .code-block-caption .headerlink::before,
        .rst-content code.download span:first-child::before,
        .rst-content dl dt .headerlink::before,
        .rst-content h1 .headerlink::before,
        .rst-content h2 .headerlink::before,
        .rst-content h3 .headerlink::before,
        .rst-content h4 .headerlink::before,
        .rst-content h5 .headerlink::before,
        .rst-content h6 .headerlink::before,
        .rst-content p.caption .headerlink::before,
        .rst-content table > caption .headerlink::before,
        .rst-content tt.download span:first-child::before,
        .wy-dropdown .caret::before,
        .wy-inline-validate.wy-inline-validate-danger .wy-input-context::before,
        .wy-inline-validate.wy-inline-validate-info .wy-input-context::before,
        .wy-inline-validate.wy-inline-validate-success .wy-input-context::before,
        .wy-inline-validate.wy-inline-validate-warning .wy-input-context::before,
        .wy-menu-vertical li.current > a span.toctree-expand::before,
        .wy-menu-vertical li.on a span.toctree-expand::before,
        .wy-menu-vertical li span.toctree-expand::before {
            text-decoration-color: inherit;
        }
        .rst-content .code-block-caption a .headerlink,
        .rst-content a .admonition-title,
        .rst-content code.download a span:first-child,
        .rst-content dl dt a .headerlink,
        .rst-content h1 a .headerlink,
        .rst-content h2 a .headerlink,
        .rst-content h3 a .headerlink,
        .rst-content h4 a .headerlink,
        .rst-content h5 a .headerlink,
        .rst-content h6 a .headerlink,
        .rst-content p.caption a .headerlink,
        .rst-content table > caption a .headerlink,
        .rst-content tt.download a span:first-child,
        .wy-menu-vertical li.current > a span.toctree-expand,
        .wy-menu-vertical li.on a span.toctree-expand,
        .wy-menu-vertical li a span.toctree-expand,
        a .fa,
        a .icon,
        a .rst-content .admonition-title,
        a .rst-content .code-block-caption .headerlink,
        a .rst-content code.download span:first-child,
        a .rst-content dl dt .headerlink,
        a .rst-content h1 .headerlink,
        a .rst-content h2 .headerlink,
        a .rst-content h3 .headerlink,
        a .rst-content h4 .headerlink,
        a .rst-content h5 .headerlink,
        a .rst-content h6 .headerlink,
        a .rst-content p.caption .headerlink,
        a .rst-content table > caption .headerlink,
        a .rst-content tt.download span:first-child,
        a .wy-menu-vertical li span.toctree-expand {
            text-decoration-color: inherit;
        }
        .rst-content .admonition,
        .rst-content .admonition-todo,
        .rst-content .attention,
        .rst-content .caution,
        .rst-content .danger,
        .rst-content .error,
        .rst-content .hint,
        .rst-content .important,
        .rst-content .note,
        .rst-content .seealso,
        .rst-content .tip,
        .rst-content .warning,
        .wy-alert {
            background-color: rgb(26, 28, 29);
            background-image: none;
        }
        .rst-content .admonition-title,
        .wy-alert-title {
            color: rgb(216, 212, 207);
            background-color: rgb(23, 73, 105);
            background-image: none;
        }
        .rst-content .danger,
        .rst-content .error,
        .rst-content .wy-alert-danger.admonition,
        .rst-content .wy-alert-danger.admonition-todo,
        .rst-content .wy-alert-danger.attention,
        .rst-content .wy-alert-danger.caution,
        .rst-content .wy-alert-danger.hint,
        .rst-content .wy-alert-danger.important,
        .rst-content .wy-alert-danger.note,
        .rst-content .wy-alert-danger.seealso,
        .rst-content .wy-alert-danger.tip,
        .rst-content .wy-alert-danger.warning,
        .wy-alert.wy-alert-danger {
            background-color: rgb(42, 10, 6);
            background-image: none;
        }
        .rst-content .danger .admonition-title,
        .rst-content .danger .wy-alert-title,
        .rst-content .error .admonition-title,
        .rst-content .error .wy-alert-title,
        .rst-content .wy-alert-danger.admonition-todo .admonition-title,
        .rst-content .wy-alert-danger.admonition-todo .wy-alert-title,
        .rst-content .wy-alert-danger.admonition .admonition-title,
        .rst-content .wy-alert-danger.admonition .wy-alert-title,
        .rst-content .wy-alert-danger.attention .admonition-title,
        .rst-content .wy-alert-danger.attention .wy-alert-title,
        .rst-content .wy-alert-danger.caution .admonition-title,
        .rst-content .wy-alert-danger.caution .wy-alert-title,
        .rst-content .wy-alert-danger.hint .admonition-title,
        .rst-content .wy-alert-danger.hint .wy-alert-title,
        .rst-content .wy-alert-danger.important .admonition-title,
        .rst-content .wy-alert-danger.important .wy-alert-title,
        .rst-content .wy-alert-danger.note .admonition-title,
        .rst-content .wy-alert-danger.note .wy-alert-title,
        .rst-content .wy-alert-danger.seealso .admonition-title,
        .rst-content .wy-alert-danger.seealso .wy-alert-title,
        .rst-content .wy-alert-danger.tip .admonition-title,
        .rst-content .wy-alert-danger.tip .wy-alert-title,
        .rst-content .wy-alert-danger.warning .admonition-title,
        .rst-content .wy-alert-danger.warning .wy-alert-title,
        .rst-content .wy-alert.wy-alert-danger .admonition-title,
        .wy-alert.wy-alert-danger .rst-content .admonition-title,
        .wy-alert.wy-alert-danger .wy-alert-title {
            background-color: rgb(86, 18, 10);
            background-image: none;
        }
        .rst-content .admonition-todo,
        .rst-content .attention,
        .rst-content .caution,
        .rst-content .warning,
        .rst-content .wy-alert-warning.admonition,
        .rst-content .wy-alert-warning.danger,
        .rst-content .wy-alert-warning.error,
        .rst-content .wy-alert-warning.hint,
        .rst-content .wy-alert-warning.important,
        .rst-content .wy-alert-warning.note,
        .rst-content .wy-alert-warning.seealso,
        .rst-content .wy-alert-warning.tip,
        .wy-alert.wy-alert-warning {
            background-color: rgb(25, 27, 28);
            background-image: none;
        }
        .rst-content .admonition-todo .admonition-title,
        .rst-content .admonition-todo .wy-alert-title,
        .rst-content .attention .admonition-title,
        .rst-content .attention .wy-alert-title,
        .rst-content .caution .admonition-title,
        .rst-content .caution .wy-alert-title,
        .rst-content .warning .admonition-title,
        .rst-content .warning .wy-alert-title,
        .rst-content .wy-alert-warning.admonition .admonition-title,
        .rst-content .wy-alert-warning.admonition .wy-alert-title,
        .rst-content .wy-alert-warning.danger .admonition-title,
        .rst-content .wy-alert-warning.danger .wy-alert-title,
        .rst-content .wy-alert-warning.error .admonition-title,
        .rst-content .wy-alert-warning.error .wy-alert-title,
        .rst-content .wy-alert-warning.hint .admonition-title,
        .rst-content .wy-alert-warning.hint .wy-alert-title,
        .rst-content .wy-alert-warning.important .admonition-title,
        .rst-content .wy-alert-warning.important .wy-alert-title,
        .rst-content .wy-alert-warning.note .admonition-title,
        .rst-content .wy-alert-warning.note .wy-alert-title,
        .rst-content .wy-alert-warning.seealso .admonition-title,
        .rst-content .wy-alert-warning.seealso .wy-alert-title,
        .rst-content .wy-alert-warning.tip .admonition-title,
        .rst-content .wy-alert-warning.tip .wy-alert-title,
        .rst-content .wy-alert.wy-alert-warning .admonition-title,
        .wy-alert.wy-alert-warning .rst-content .admonition-title,
        .wy-alert.wy-alert-warning .wy-alert-title {
            background-color: rgb(98, 52, 11);
            background-image: none;
        }
        .rst-content .note,
        .rst-content .seealso,
        .rst-content .wy-alert-info.admonition,
        .rst-content .wy-alert-info.admonition-todo,
        .rst-content .wy-alert-info.attention,
        .rst-content .wy-alert-info.caution,
        .rst-content .wy-alert-info.danger,
        .rst-content .wy-alert-info.error,
        .rst-content .wy-alert-info.hint,
        .rst-content .wy-alert-info.important,
        .rst-content .wy-alert-info.tip,
        .rst-content .wy-alert-info.warning,
        .wy-alert.wy-alert-info {
            background-color: rgb(26, 28, 29);
            background-image: none;
        }
        .rst-content .note .admonition-title,
        .rst-content .note .wy-alert-title,
        .rst-content .seealso .admonition-title,
        .rst-content .seealso .wy-alert-title,
        .rst-content .wy-alert-info.admonition-todo .admonition-title,
        .rst-content .wy-alert-info.admonition-todo .wy-alert-title,
        .rst-content .wy-alert-info.admonition .admonition-title,
        .rst-content .wy-alert-info.admonition .wy-alert-title,
        .rst-content .wy-alert-info.attention .admonition-title,
        .rst-content .wy-alert-info.attention .wy-alert-title,
        .rst-content .wy-alert-info.caution .admonition-title,
        .rst-content .wy-alert-info.caution .wy-alert-title,
        .rst-content .wy-alert-info.danger .admonition-title,
        .rst-content .wy-alert-info.danger .wy-alert-title,
        .rst-content .wy-alert-info.error .admonition-title,
        .rst-content .wy-alert-info.error .wy-alert-title,
        .rst-content .wy-alert-info.hint .admonition-title,
        .rst-content .wy-alert-info.hint .wy-alert-title,
        .rst-content .wy-alert-info.important .admonition-title,
        .rst-content .wy-alert-info.important .wy-alert-title,
        .rst-content .wy-alert-info.tip .admonition-title,
        .rst-content .wy-alert-info.tip .wy-alert-title,
        .rst-content .wy-alert-info.warning .admonition-title,
        .rst-content .wy-alert-info.warning .wy-alert-title,
        .rst-content .wy-alert.wy-alert-info .admonition-title,
        .wy-alert.wy-alert-info .rst-content .admonition-title,
        .wy-alert.wy-alert-info .wy-alert-title {
            background-color: rgb(23, 73, 105);
            background-image: none;
        }
        .rst-content .hint,
        .rst-content .important,
        .rst-content .tip,
        .rst-content .wy-alert-success.admonition,
        .rst-content .wy-alert-success.admonition-todo,
        .rst-content .wy-alert-success.attention,
        .rst-content .wy-alert-success.caution,
        .rst-content .wy-alert-success.danger,
        .rst-content .wy-alert-success.error,
        .rst-content .wy-alert-success.note,
        .rst-content .wy-alert-success.seealso,
        .rst-content .wy-alert-success.warning,
        .wy-alert.wy-alert-success {
            background-color: rgb(7, 53, 46);
            background-image: none;
        }
        .rst-content .hint .admonition-title,
        .rst-content .hint .wy-alert-title,
        .rst-content .important .admonition-title,
        .rst-content .important .wy-alert-title,
        .rst-content .tip .admonition-title,
        .rst-content .tip .wy-alert-title,
        .rst-content .wy-alert-success.admonition-todo .admonition-title,
        .rst-content .wy-alert-success.admonition-todo .wy-alert-title,
        .rst-content .wy-alert-success.admonition .admonition-title,
        .rst-content .wy-alert-success.admonition .wy-alert-title,
        .rst-content .wy-alert-success.attention .admonition-title,
        .rst-content .wy-alert-success.attention .wy-alert-title,
        .rst-content .wy-alert-success.caution .admonition-title,
        .rst-content .wy-alert-success.caution .wy-alert-title,
        .rst-content .wy-alert-success.danger .admonition-title,
        .rst-content .wy-alert-success.danger .wy-alert-title,
        .rst-content .wy-alert-success.error .admonition-title,
        .rst-content .wy-alert-success.error .wy-alert-title,
        .rst-content .wy-alert-success.note .admonition-title,
        .rst-content .wy-alert-success.note .wy-alert-title,
        .rst-content .wy-alert-success.seealso .admonition-title,
        .rst-content .wy-alert-success.seealso .wy-alert-title,
        .rst-content .wy-alert-success.warning .admonition-title,
        .rst-content .wy-alert-success.warning .wy-alert-title,
        .rst-content .wy-alert.wy-alert-success .admonition-title,
        .wy-alert.wy-alert-success .rst-content .admonition-title,
        .wy-alert.wy-alert-success .wy-alert-title {
            background-color: rgb(17, 120, 100);
            background-image: none;
        }
        .rst-content .wy-alert-neutral.admonition,
        .rst-content .wy-alert-neutral.admonition-todo,
        .rst-content .wy-alert-neutral.attention,
        .rst-content .wy-alert-neutral.caution,
        .rst-content .wy-alert-neutral.danger,
        .rst-content .wy-alert-neutral.error,
        .rst-content .wy-alert-neutral.hint,
        .rst-content .wy-alert-neutral.important,
        .rst-content .wy-alert-neutral.note,
        .rst-content .wy-alert-neutral.seealso,
        .rst-content .wy-alert-neutral.tip,
        .rst-content .wy-alert-neutral.warning,
        .wy-alert.wy-alert-neutral {
            background-color: rgb(22, 29, 29);
            background-image: none;
        }
        .rst-content .wy-alert-neutral.admonition-todo .admonition-title,
        .rst-content .wy-alert-neutral.admonition-todo .wy-alert-title,
        .rst-content .wy-alert-neutral.admonition .admonition-title,
        .rst-content .wy-alert-neutral.admonition .wy-alert-title,
        .rst-content .wy-alert-neutral.attention .admonition-title,
        .rst-content .wy-alert-neutral.attention .wy-alert-title,
        .rst-content .wy-alert-neutral.caution .admonition-title,
        .rst-content .wy-alert-neutral.caution .wy-alert-title,
        .rst-content .wy-alert-neutral.danger .admonition-title,
        .rst-content .wy-alert-neutral.danger .wy-alert-title,
        .rst-content .wy-alert-neutral.error .admonition-title,
        .rst-content .wy-alert-neutral.error .wy-alert-title,
        .rst-content .wy-alert-neutral.hint .admonition-title,
        .rst-content .wy-alert-neutral.hint .wy-alert-title,
        .rst-content .wy-alert-neutral.important .admonition-title,
        .rst-content .wy-alert-neutral.important .wy-alert-title,
        .rst-content .wy-alert-neutral.note .admonition-title,
        .rst-content .wy-alert-neutral.note .wy-alert-title,
        .rst-content .wy-alert-neutral.seealso .admonition-title,
        .rst-content .wy-alert-neutral.seealso .wy-alert-title,
        .rst-content .wy-alert-neutral.tip .admonition-title,
        .rst-content .wy-alert-neutral.tip .wy-alert-title,
        .rst-content .wy-alert-neutral.warning .admonition-title,
        .rst-content .wy-alert-neutral.warning .wy-alert-title,
        .rst-content .wy-alert.wy-alert-neutral .admonition-title,
        .wy-alert.wy-alert-neutral .rst-content .admonition-title,
        .wy-alert.wy-alert-neutral .wy-alert-title {
            color: rgb(188, 182, 173);
            background-color: rgb(32, 35, 36);
            background-image: none;
        }
        .rst-content .wy-alert-neutral.admonition-todo a,
        .rst-content .wy-alert-neutral.admonition a,
        .rst-content .wy-alert-neutral.attention a,
        .rst-content .wy-alert-neutral.caution a,
        .rst-content .wy-alert-neutral.danger a,
        .rst-content .wy-alert-neutral.error a,
        .rst-content .wy-alert-neutral.hint a,
        .rst-content .wy-alert-neutral.important a,
        .rst-content .wy-alert-neutral.note a,
        .rst-content .wy-alert-neutral.seealso a,
        .rst-content .wy-alert-neutral.tip a,
        .rst-content .wy-alert-neutral.warning a,
        .wy-alert.wy-alert-neutral a {
            color: rgb(94, 169, 219);
        }
        .wy-tray-container li {
            background-color: transparent;
            background-image: none;
            color: rgb(216, 212, 207);
            box-shadow: rgba(0, 0, 0, 0.1) 0px 5px 5px 0px;
        }
        .wy-tray-container li.wy-tray-item-success {
            background-color: rgb(25, 111, 62);
            background-image: none;
        }
        .wy-tray-container li.wy-tray-item-info {
            background-color: rgb(26, 82, 118);
            background-image: none;
        }
        .wy-tray-container li.wy-tray-item-warning {
            background-color: rgb(142, 75, 16);
            background-image: none;
        }
        .wy-tray-container li.wy-tray-item-danger {
            background-color: rgb(130, 26, 16);
            background-image: none;
        }
        .btn {
            color: rgb(216, 212, 207);
            border-color: rgba(84, 91, 95, 0.1);
            background-color: rgb(25, 111, 62);
            text-decoration-color: currentcolor;
            box-shadow: rgba(19, 21, 22, 0.5) 0px 1px 2px -1px inset,
            rgba(0, 0, 0, 0.1) 0px -2px 0px 0px inset;
        }
        .btn-hover {
            background-color: rgb(30, 91, 132);
            background-image: none;
            color: rgb(216, 212, 207);
        }
        .btn:hover {
            background-color: rgb(28, 125, 69);
            background-image: none;
            color: rgb(216, 212, 207);
        }
        .btn:focus {
            background-color: rgb(28, 125, 69);
            background-image: none;
            outline-color: currentcolor;
        }
        .btn:active {
            box-shadow: rgba(0, 0, 0, 0.05) 0px -1px 0px 0px inset,
            rgba(0, 0, 0, 0.1) 0px 2px 0px 0px inset;
        }
        .btn:visited {
            color: rgb(216, 212, 207);
        }
        .btn-disabled,
        .btn-disabled:active,
        .btn-disabled:focus,
        .btn-disabled:hover,
        .btn:disabled {
            background-image: none;
            box-shadow: none;
        }
        .btn-info {
            background-color: rgb(26, 82, 118) !important;
        }
        .btn-info:hover {
            background-color: rgb(30, 91, 132) !important;
        }
        .btn-neutral {
            background-color: rgb(22, 29, 29) !important;
            color: rgb(188, 182, 173) !important;
        }
        .btn-neutral:hover {
            color: rgb(188, 182, 173);
            background-color: rgb(27, 35, 35) !important;
        }
        .btn-neutral:visited {
            color: rgb(188, 182, 173) !important;
        }
        .btn-success {
            background-color: rgb(25, 111, 62) !important;
        }
        .btn-success:hover {
            background-color: rgb(22, 98, 54) !important;
        }
        .btn-danger {
            background-color: rgb(130, 26, 16) !important;
        }
        .btn-danger:hover {
            background-color: rgb(119, 24, 14) !important;
        }
        .btn-warning {
            background-color: rgb(142, 75, 16) !important;
        }
        .btn-warning:hover {
            background-color: rgb(132, 70, 14) !important;
        }
        .btn-invert {
            background-color: rgb(21, 22, 23);
        }
        .btn-invert:hover {
            background-color: rgb(28, 31, 32) !important;
        }
        .btn-link {
            color: rgb(94, 169, 219);
            box-shadow: none;
            background-color: transparent !important;
            border-color: transparent !important;
        }
        .btn-link:active,
        .btn-link:hover {
            box-shadow: none;
            background-color: transparent !important;
            color: rgb(90, 168, 218) !important;
        }
        .btn-link:visited {
            color: rgb(170, 113, 192);
        }
        .wy-dropdown-menu {
            background-color: rgb(21, 22, 23);
            background-image: none;
            border-color: rgb(119, 111, 98);
            box-shadow: rgba(0, 0, 0, 0.1) 0px 2px 2px 0px;
        }
        .wy-dropdown-menu > dd > a {
            color: rgb(188, 182, 173);
        }
        .wy-dropdown-menu > dd > a:hover {
            background-color: rgb(26, 82, 118);
            background-image: none;
            color: rgb(216, 212, 207);
        }
        .wy-dropdown-menu > dd.divider {
            border-top-color: rgb(119, 111, 98);
        }
        .wy-dropdown-menu > dd.call-to-action {
            background-color: rgb(32, 35, 36);
            background-image: none;
        }
        .wy-dropdown-menu > dd.call-to-action:hover {
            background-color: rgb(32, 35, 36);
            background-image: none;
        }
        .wy-dropdown-menu > dd.call-to-action .btn {
            color: rgb(216, 212, 207);
        }
        .wy-dropdown.wy-dropdown-bubble .wy-dropdown-menu {
            background-color: rgb(21, 22, 23);
            background-image: none;
        }
        .wy-dropdown.wy-dropdown-bubble .wy-dropdown-menu a:hover {
            background-color: rgb(26, 82, 118);
            background-image: none;
            color: rgb(216, 212, 207);
        }
        .wy-dropdown-arrow::before {
            border-bottom-color: rgb(122, 113, 100);
            border-left-color: transparent;
            border-right-color: transparent;
        }
        fieldset,
        legend {
            border-color: currentcolor;
        }
        label {
            color: rgb(193, 188, 180);
        }
        .wy-control-group.wy-control-group-required > label::after {
            color: rgb(234, 96, 82);
        }
        .wy-form-message-inline {
            color: rgb(171, 164, 153);
        }
        .wy-form-message {
            color: rgb(171, 164, 153);
        }
        input[type="color"], input[type="date"], input[type="datetime-local"], input[type="datetime"], input[type="email"], input[type="month"], input[type="number"], input[type="password"], input[type="search"], input[type="tel"], input[type="text"], input[type="time"], input[type="url"], input[type="week"] {
            border-color: rgb(118, 110, 97);
            box-shadow: rgb(35, 38, 39) 0px 1px 3px inset;
        }
        input[type="color"]:focus, input[type="date"]:focus, input[type="datetime-local"]:focus, input[type="datetime"]:focus, input[type="email"]:focus, input[type="month"]:focus, input[type="number"]:focus, input[type="password"]:focus, input[type="search"]:focus, input[type="tel"]:focus, input[type="text"]:focus, input[type="time"]:focus, input[type="url"]:focus, input[type="week"]:focus {
            outline-color: currentcolor;
            border-color: rgb(103, 96, 85);
        }
        input.no-focus:focus {
            border-color: rgb(118, 110, 97) !important;
        }
        input[type="checkbox"]:focus, input[type="file"]:focus, input[type="radio"]:focus {
            outline-color: rgb(15, 126, 186);
        }
        input[type="color"][disabled], input[type="date"][disabled], input[type="datetime-local"][disabled], input[type="datetime"][disabled], input[type="email"][disabled], input[type="month"][disabled], input[type="number"][disabled], input[type="password"][disabled], input[type="search"][disabled], input[type="tel"][disabled], input[type="text"][disabled], input[type="time"][disabled], input[type="url"][disabled], input[type="week"][disabled] {
            background-color: rgb(21, 23, 24);
        }
        input:focus:invalid,
        select:focus:invalid,
        textarea:focus:invalid {
            color: rgb(234, 96, 82);
            border-color: rgb(183, 38, 22);
        }
        input:focus:invalid:focus,
        select:focus:invalid:focus,
        textarea:focus:invalid:focus {
            border-color: rgb(183, 38, 22);
        }
        input[type="checkbox"]:focus:invalid:focus, input[type="file"]:focus:invalid:focus, input[type="radio"]:focus:invalid:focus {
            outline-color: rgb(183, 38, 22);
        }
        select,
        textarea {
            border-color: rgb(118, 110, 97);
            box-shadow: rgb(35, 38, 39) 0px 1px 3px inset;
        }
        select {
            border-color: rgb(118, 110, 97);
            background-color: rgb(19, 21, 22);
        }
        select:focus,
        textarea:focus {
            outline-color: currentcolor;
        }
        input[readonly],
        select[disabled],
        select[readonly],
        textarea[disabled],
        textarea[readonly] {
            background-color: rgb(21, 23, 24);
        }
        .wy-checkbox,
        .wy-radio {
            color: rgb(188, 182, 173);
        }
        .wy-input-prefix .wy-input-context,
        .wy-input-suffix .wy-input-context {
            background-color: rgb(22, 29, 29);
            border-color: rgb(118, 110, 97);
            color: rgb(171, 164, 153);
        }
        .wy-input-suffix .wy-input-context {
            border-left-color: currentcolor;
        }
        .wy-input-prefix .wy-input-context {
            border-right-color: currentcolor;
        }
        .wy-switch::before {
            background-color: rgb(42, 46, 47);
            background-image: none;
        }
        .wy-switch::after {
            background-color: rgb(66, 71, 74);
            background-image: none;
        }
        .wy-switch span {
            color: rgb(193, 188, 180);
        }
        .wy-switch.active::before {
            background-color: rgb(19, 85, 46);
            background-image: none;
        }
        .wy-switch.active::after {
            background-color: rgb(25, 111, 62);
            background-image: none;
        }
        .wy-control-group.wy-control-group-error .wy-form-message,
        .wy-control-group.wy-control-group-error > label {
            color: rgb(234, 96, 82);
        }
        .wy-control-group.wy-control-group-error input[type="color"], .wy-control-group.wy-control-group-error input[type="date"], .wy-control-group.wy-control-group-error input[type="datetime-local"], .wy-control-group.wy-control-group-error input[type="datetime"], .wy-control-group.wy-control-group-error input[type="email"], .wy-control-group.wy-control-group-error input[type="month"], .wy-control-group.wy-control-group-error input[type="number"], .wy-control-group.wy-control-group-error input[type="password"], .wy-control-group.wy-control-group-error input[type="search"], .wy-control-group.wy-control-group-error input[type="tel"], .wy-control-group.wy-control-group-error input[type="text"], .wy-control-group.wy-control-group-error input[type="time"], .wy-control-group.wy-control-group-error input[type="url"], .wy-control-group.wy-control-group-error input[type="week"],
        .wy-control-group.wy-control-group-error textarea {
            border-color: rgb(183, 38, 22);
        }
        .wy-inline-validate.wy-inline-validate-success .wy-input-context {
            color: rgb(99, 220, 150);
        }
        .wy-inline-validate.wy-inline-validate-danger .wy-input-context {
            color: rgb(234, 96, 82);
        }
        .wy-inline-validate.wy-inline-validate-warning .wy-input-context {
            color: rgb(234, 146, 69);
        }
        .wy-inline-validate.wy-inline-validate-info .wy-input-context {
            color: rgb(94, 169, 219);
        }
        .rst-content table.docutils caption,
        .rst-content table.field-list caption,
        .wy-table caption {
            color: rgb(216, 212, 207);
        }
        .rst-content table.docutils thead,
        .rst-content table.field-list thead,
        .wy-table thead {
            color: rgb(216, 212, 207);
        }
        .rst-content table.docutils thead th,
        .rst-content table.field-list thead th,
        .wy-table thead th {
            border-bottom-color: rgb(120, 112, 99);
        }
        .rst-content table.docutils td,
        .rst-content table.field-list td,
        .wy-table td {
            background-color: transparent;
        }
        .wy-table-secondary {
            color: rgb(160, 151, 139);
        }
        .wy-table-tertiary {
            color: rgb(160, 151, 139);
        }
        .rst-content table.docutils:not(.field-list) tr:nth-child(2n-1) td,
        .wy-table-backed,
        .wy-table-odd td,
        .wy-table-striped tr:nth-child(2n-1) td {
            background-color: rgb(22, 29, 29);
        }
        .rst-content table.docutils,
        .wy-table-bordered-all {
            border-color: rgb(120, 112, 99);
        }
        .rst-content table.docutils td,
        .wy-table-bordered-all td {
            border-bottom-color: rgb(120, 112, 99);
            border-left-color: rgb(120, 112, 99);
        }
        .wy-table-bordered {
            border-color: rgb(120, 112, 99);
        }
        .wy-table-bordered-rows td {
            border-bottom-color: rgb(120, 112, 99);
        }
        .wy-table-horizontal td,
        .wy-table-horizontal th {
            border-bottom-color: rgb(120, 112, 99);
        }
        a {
            color: rgb(94, 169, 219);
            text-decoration-color: currentcolor;
        }
        a:hover {
            color: rgb(82, 164, 217);
        }
        a:visited {
            color: rgb(170, 113, 192);
        }
        body {
            color: rgb(188, 182, 173);
            background-color: rgb(26, 29, 30);
            background-image: none;
        }
        .wy-text-strike {
            text-decoration-color: currentcolor;
        }
        .wy-text-warning {
            color: rgb(234, 146, 69) !important;
        }
        a.wy-text-warning:hover {
            color: rgb(237, 160, 92) !important;
        }
        .wy-text-info {
            color: rgb(94, 169, 219) !important;
        }
        a.wy-text-info:hover {
            color: rgb(90, 168, 218) !important;
        }
        .wy-text-success {
            color: rgb(99, 220, 150) !important;
        }
        a.wy-text-success:hover {
            color: rgb(86, 217, 142) !important;
        }
        .wy-text-danger {
            color: rgb(234, 96, 82) !important;
        }
        a.wy-text-danger:hover {
            color: rgb(237, 118, 104) !important;
        }
        .wy-text-neutral {
            color: rgb(188, 182, 173) !important;
        }
        a.wy-text-neutral:hover {
            color: rgb(177, 170, 160) !important;
        }
        hr {
            border-color: rgb(120, 112, 99) currentcolor currentcolor;
        }
        .rst-content code,
        .rst-content tt,
        code {
            background-color: rgb(19, 21, 22);
            background-image: none;
            border-color: rgb(120, 112, 99);
            color: rgb(234, 96, 82);
        }
        .rst-content .section ul,
        .rst-content .toctree-wrapper ul,
        .wy-plain-list-disc,
        article ul {
            list-style-image: none;
        }
        .rst-content .section ul li,
        .rst-content .toctree-wrapper ul li,
        .wy-plain-list-disc li,
        article ul li {
            list-style-image: none;
        }
        .rst-content .section ul li li,
        .rst-content .toctree-wrapper ul li li,
        .wy-plain-list-disc li li,
        article ul li li {
            list-style-image: none;
        }
        .rst-content .section ul li li li,
        .rst-content .toctree-wrapper ul li li li,
        .wy-plain-list-disc li li li,
        article ul li li li {
            list-style-image: none;
        }
        .rst-content .section ul li ol li,
        .rst-content .toctree-wrapper ul li ol li,
        .wy-plain-list-disc li ol li,
        article ul li ol li {
            list-style-image: none;
        }
        .rst-content .section ol,
        .rst-content ol.arabic,
        .wy-plain-list-decimal,
        article ol {
            list-style-image: none;
        }
        .rst-content .section ol li,
        .rst-content ol.arabic li,
        .wy-plain-list-decimal li,
        article ol li {
            list-style-image: none;
        }
        .rst-content .section ol li ul li,
        .rst-content ol.arabic li ul li,
        .wy-plain-list-decimal li ul li,
        article ol li ul li {
            list-style-image: none;
        }
        .rst-content .wy-breadcrumbs li tt,
        .wy-breadcrumbs li .rst-content tt,
        .wy-breadcrumbs li code {
            border-color: currentcolor;
            background-color: rgba(0, 0, 0, 0);
            background-image: none;
        }
        .rst-content .wy-breadcrumbs li tt.literal,
        .wy-breadcrumbs li .rst-content tt.literal,
        .wy-breadcrumbs li code.literal {
            color: rgb(188, 182, 173);
        }
        .wy-breadcrumbs-extra {
            color: rgb(182, 176, 167);
        }
        .wy-menu a:hover {
            text-decoration-color: currentcolor;
        }
        .wy-menu-horiz li:hover {
            background-color: rgba(19, 21, 22, 0.1);
            background-image: none;
        }
        .wy-menu-horiz li.divide-left {
            border-left-color: rgb(104, 97, 86);
        }
        .wy-menu-horiz li.divide-right {
            border-right-color: rgb(104, 97, 86);
        }
        .wy-menu-vertical header,
        .wy-menu-vertical p.caption {
            color: rgb(101, 173, 220);
        }
        .wy-menu-vertical li.divide-top {
            border-top-color: rgb(104, 97, 86);
        }
        .wy-menu-vertical li.divide-bottom {
            border-bottom-color: rgb(104, 97, 86);
        }
        .wy-menu-vertical li.current {
            background-color: rgb(32, 35, 36);
            background-image: none;
        }
        .wy-menu-vertical li.current a {
            color: rgb(160, 151, 139);
            border-right-color: rgb(118, 110, 97);
        }
        .wy-menu-vertical li.current a:hover {
            background-color: rgb(38, 41, 42);
            background-image: none;
        }
        .rst-content .wy-menu-vertical li tt,
        .wy-menu-vertical li .rst-content tt,
        .wy-menu-vertical li code {
            border-color: currentcolor;
            background-color: inherit;
            background-image: inherit;
            color: inherit;
        }
        .wy-menu-vertical li span.toctree-expand {
            color: rgb(182, 175, 166);
        }
        .wy-menu-vertical li.current > a,
        .wy-menu-vertical li.on a {
            color: rgb(188, 182, 173);
            background-color: rgb(21, 22, 23);
            background-image: none;
            border-color: currentcolor;
        }
        .wy-menu-vertical li.current > a:hover,
        .wy-menu-vertical li.on a:hover {
            background-color: rgb(21, 22, 23);
            background-image: none;
        }
        .wy-menu-vertical li.current > a:hover span.toctree-expand,
        .wy-menu-vertical li.on a:hover span.toctree-expand {
            color: rgb(160, 151, 139);
        }
        .wy-menu-vertical li.current > a span.toctree-expand,
        .wy-menu-vertical li.on a span.toctree-expand {
            color: rgb(193, 188, 180);
        }
        .wy-menu-vertical li.toctree-l1.current > a {
            border-bottom-color: rgb(118, 110, 97);
            border-top-color: rgb(118, 110, 97);
        }
        .wy-menu-vertical li.toctree-l2 a,
        .wy-menu-vertical li.toctree-l3 a,
        .wy-menu-vertical li.toctree-l4 a,
        .wy-menu-vertical li.toctree-l5 a,
        .wy-menu-vertical li.toctree-l6 a,
        .wy-menu-vertical li.toctree-l7 a,
        .wy-menu-vertical li.toctree-l8 a,
        .wy-menu-vertical li.toctree-l9 a,
        .wy-menu-vertical li.toctree-l10 a {
            color: rgb(188, 182, 173);
        }
        .wy-menu-vertical li.toctree-l2 a:hover span.toctree-expand,
        .wy-menu-vertical li.toctree-l3 a:hover span.toctree-expand,
        .wy-menu-vertical li.toctree-l4 a:hover span.toctree-expand,
        .wy-menu-vertical li.toctree-l5 a:hover span.toctree-expand,
        .wy-menu-vertical li.toctree-l6 a:hover span.toctree-expand,
        .wy-menu-vertical li.toctree-l7 a:hover span.toctree-expand,
        .wy-menu-vertical li.toctree-l8 a:hover span.toctree-expand,
        .wy-menu-vertical li.toctree-l9 a:hover span.toctree-expand,
        .wy-menu-vertical li.toctree-l10 a:hover span.toctree-expand {
            color: rgb(160, 151, 139);
        }
        .wy-menu-vertical li.toctree-l2.current > a,
        .wy-menu-vertical li.toctree-l2.current li.toctree-l3 > a {
            background-color: rgb(43, 47, 49);
            background-image: none;
        }
        .wy-menu-vertical li.toctree-l2 span.toctree-expand {
            color: rgb(175, 168, 158);
        }
        .wy-menu-vertical li.toctree-l3.current > a,
        .wy-menu-vertical li.toctree-l3.current li.toctree-l4 > a {
            background-color: rgb(49, 53, 55);
            background-image: none;
        }
        .wy-menu-vertical li.toctree-l3 span.toctree-expand {
            color: rgb(169, 162, 151);
        }
        .wy-menu-vertical li ul li a {
            color: rgb(199, 194, 187);
        }
        .wy-menu-vertical a {
            color: rgb(199, 194, 187);
        }
        .wy-menu-vertical a:hover {
            background-color: rgb(46, 49, 51);
        }
        .wy-menu-vertical a:hover span.toctree-expand {
            color: rgb(199, 194, 187);
        }
        .wy-menu-vertical a:active {
            background-color: rgb(26, 82, 118);
            color: rgb(216, 212, 207);
        }
        .wy-menu-vertical a:active span.toctree-expand {
            color: rgb(216, 212, 207);
        }
        .wy-side-nav-search {
            background-color: rgb(26, 82, 118);
            color: rgb(215, 211, 206);
        }
        .wy-side-nav-search input[type="text"] {
            border-color: rgb(35, 112, 161);
        }
        .wy-side-nav-search img {
            background-color: rgb(26, 82, 118);
        }
        .wy-side-nav-search .wy-dropdown > a,
        .wy-side-nav-search > a {
            color: rgb(215, 211, 206);
        }
        .wy-side-nav-search .wy-dropdown > a:hover,
        .wy-side-nav-search > a:hover {
            background-color: rgba(19, 21, 22, 0.1);
            background-image: none;
        }
        .wy-side-nav-search .wy-dropdown > a img.logo,
        .wy-side-nav-search > a img.logo {
            background-color: transparent;
            background-image: none;
        }
        .wy-side-nav-search > div.version {
            color: rgba(216, 212, 207, 0.3);
        }
        .wy-nav .wy-menu-vertical header {
            color: rgb(94, 169, 219);
        }
        .wy-nav .wy-menu-vertical a {
            color: rgb(182, 176, 167);
        }
        .wy-nav .wy-menu-vertical a:hover {
            background-color: rgb(26, 82, 118);
            color: rgb(216, 212, 207);
        }
        .wy-body-for-nav {
            background-color: rgb(21, 22, 23);
            background-image: none;
        }
        .wy-nav-side {
            color: rgb(172, 164, 154);
            background-color: rgb(30, 33, 34);
            background-image: none;
        }
        .wy-nav-top {
            background-color: rgb(26, 82, 118);
            background-image: none;
            color: rgb(216, 212, 207);
        }
        .wy-nav-top a {
            color: rgb(216, 212, 207);
        }
        .wy-nav-top img {
            background-color: rgb(26, 82, 118);
        }
        .wy-nav-content-wrap {
            background-color: rgb(21, 22, 23);
            background-image: none;
        }
        .wy-body-mask {
            background-color: rgba(0, 0, 0, 0.2);
            background-image: none;
        }
        footer {
            color: rgb(160, 151, 139);
        }
        .rst-content footer span.commit tt,
        footer span.commit .rst-content tt,
        footer span.commit code {
            background-color: rgba(0, 0, 0, 0);
            background-image: none;
            border-color: currentcolor;
            color: rgb(160, 151, 139);
        }
        #search-results .search li {
            border-bottom-color: rgb(120, 112, 99);
        }
        #search-results .search li:first-child {
            border-top-color: rgb(120, 112, 99);
        }
        #search-results .context {
            color: rgb(160, 151, 139);
        }
        .wy-body-for-nav {
            background-color: rgb(21, 22, 23);
            background-image: none;
        }
        @media screen and (min-width: 1100px) {
            .wy-nav-content-wrap {
                background-color: rgba(0, 0, 0, 0.05);
                background-image: none;
            }
            .wy-nav-content {
                background-color: rgb(21, 22, 23);
                background-image: none;
            }
        }
        .rst-versions {
            color: rgb(215, 211, 206);
            background-color: rgb(18, 20, 20);
            background-image: none;
        }
        .rst-versions a {
            color: rgb(94, 169, 219);
            text-decoration-color: currentcolor;
        }
        .rst-versions .rst-current-version {
            background-color: rgb(23, 25, 26);
            color: rgb(99, 220, 150);
        }
        .rst-content .code-block-caption .rst-versions .rst-current-version .headerlink,
        .rst-content .rst-versions .rst-current-version .admonition-title,
        .rst-content code.download .rst-versions .rst-current-version span:first-child,
        .rst-content dl dt .rst-versions .rst-current-version .headerlink,
        .rst-content h1 .rst-versions .rst-current-version .headerlink,
        .rst-content h2 .rst-versions .rst-current-version .headerlink,
        .rst-content h3 .rst-versions .rst-current-version .headerlink,
        .rst-content h4 .rst-versions .rst-current-version .headerlink,
        .rst-content h5 .rst-versions .rst-current-version .headerlink,
        .rst-content h6 .rst-versions .rst-current-version .headerlink,
        .rst-content p.caption .rst-versions .rst-current-version .headerlink,
        .rst-content table > caption .rst-versions .rst-current-version .headerlink,
        .rst-content tt.download .rst-versions .rst-current-version span:first-child,
        .rst-versions .rst-current-version .fa,
        .rst-versions .rst-current-version .icon,
        .rst-versions .rst-current-version .rst-content .admonition-title,
        .rst-versions .rst-current-version .rst-content .code-block-caption .headerlink,
        .rst-versions .rst-current-version .rst-content code.download span:first-child,
        .rst-versions .rst-current-version .rst-content dl dt .headerlink,
        .rst-versions .rst-current-version .rst-content h1 .headerlink,
        .rst-versions .rst-current-version .rst-content h2 .headerlink,
        .rst-versions .rst-current-version .rst-content h3 .headerlink,
        .rst-versions .rst-current-version .rst-content h4 .headerlink,
        .rst-versions .rst-current-version .rst-content h5 .headerlink,
        .rst-versions .rst-current-version .rst-content h6 .headerlink,
        .rst-versions .rst-current-version .rst-content p.caption .headerlink,
        .rst-versions .rst-current-version .rst-content table > caption .headerlink,
        .rst-versions .rst-current-version .rst-content tt.download span:first-child,
        .rst-versions .rst-current-version .wy-menu-vertical li span.toctree-expand,
        .wy-menu-vertical li .rst-versions .rst-current-version span.toctree-expand {
            color: rgb(215, 211, 206);
        }
        .rst-versions .rst-current-version.rst-out-of-date {
            background-color: rgb(130, 26, 16);
            color: rgb(216, 212, 207);
        }
        .rst-versions .rst-current-version.rst-active-old-version {
            background-color: rgb(154, 125, 9);
            color: rgb(216, 212, 207);
        }
        .rst-versions .rst-other-versions {
            color: rgb(160, 151, 139);
        }
        .rst-versions .rst-other-versions hr {
            border-color: rgb(104, 97, 86) currentcolor currentcolor;
        }
        .rst-versions .rst-other-versions dd a {
            color: rgb(215, 211, 206);
        }
        .rst-versions.rst-badge {
            border-color: currentcolor;
        }
        .rst-content abbr[title] {
            text-decoration-color: currentcolor;
        }
        .rst-content.style-external-links a.reference.external::after {
            color: rgb(182, 176, 167);
        }
        .rst-content div[class^="highlight"],
        .rst-content pre.literal-block {
            border-color: rgb(120, 112, 99);
        }
        .rst-content div[class^="highlight"] div[class^="highlight"], .rst-content pre.literal-block div[class^="highlight"] {
            border-color: currentcolor;
        }
        .rst-content .linenodiv pre {
            border-right-color: rgb(121, 112, 99);
        }
        .rst-content .admonition table {
            border-color: rgba(84, 91, 95, 0.1);
        }
        .rst-content .admonition table td,
        .rst-content .admonition table th {
            background-color: transparent !important;
            background-image: none !important;
            border-color: rgba(84, 91, 95, 0.1) !important;
        }
        .rst-content .section ol.loweralpha,
        .rst-content .section ol.loweralpha > li {
            list-style-image: none;
        }
        .rst-content .section ol.upperalpha,
        .rst-content .section ol.upperalpha > li {
            list-style-image: none;
        }
        .rst-content .toc-backref {
            color: rgb(188, 182, 173);
        }
        .rst-content .sidebar {
            background-color: rgb(22, 29, 29);
            background-image: none;
            border-color: rgb(120, 112, 99);
        }
        .rst-content .sidebar .sidebar-title {
            background-color: rgb(32, 35, 36);
            background-image: none;
        }
        .rst-content .highlighted {
            background-color: rgb(154, 125, 9);
            background-image: none;
            box-shadow: rgb(154, 125, 9) 0px 0px 0px 2px;
        }
        html.writer-html4 .rst-content table.docutils.citation,
        html.writer-html4 .rst-content table.docutils.footnote {
            background-color: rgba(0, 0, 0, 0);
            background-image: none;
            border-color: currentcolor;
        }
        html.writer-html4 .rst-content table.docutils.citation td,
        html.writer-html4 .rst-content table.docutils.citation tr,
        html.writer-html4 .rst-content table.docutils.footnote td,
        html.writer-html4 .rst-content table.docutils.footnote tr {
            border-color: currentcolor;
            background-color: transparent !important;
        }
        .rst-content table.docutils.footnote,
        html.writer-html4 .rst-content table.docutils.citation,
        html.writer-html5 .rst-content dl.footnote {
            color: rgb(160, 151, 139);
        }
        .rst-content table.docutils.footnote code,
        .rst-content table.docutils.footnote tt,
        html.writer-html4 .rst-content table.docutils.citation code,
        html.writer-html4 .rst-content table.docutils.citation tt,
        html.writer-html5 .rst-content dl.footnote code,
        html.writer-html5 .rst-content dl.footnote tt {
            color: rgb(178, 172, 162);
        }
        .rst-content table.docutils th {
            border-color: rgb(120, 112, 99);
        }
        html.writer-html5 .rst-content table.docutils th {
            border-color: rgb(120, 112, 99);
        }
        .rst-content table.field-list,
        .rst-content table.field-list td {
            border-color: currentcolor;
        }
        .rst-content code,
        .rst-content tt {
            color: rgb(216, 212, 207);
        }
        .rst-content code.literal,
        .rst-content tt.literal {
            color: rgb(227, 134, 124);
        }
        .rst-content code.xref,
        .rst-content tt.xref,
        a .rst-content code,
        a .rst-content tt {
            color: rgb(188, 182, 173);
        }
        .rst-content a code,
        .rst-content a tt {
            color: rgb(94, 169, 219);
        }
        html.writer-html4 .rst-content dl:not(.docutils) > dt,
        html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) > dt {
            background-color: rgb(26, 28, 29);
            background-image: none;
            color: rgb(94, 169, 219);
            border-top-color: rgb(37, 119, 171);
        }
        html.writer-html4 .rst-content dl:not(.docutils) > dt::before,
        html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) > dt::before {
            color: rgb(111, 179, 223);
        }
        html.writer-html4 .rst-content dl:not(.docutils) > dt .headerlink,
        html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) > dt .headerlink {
            color: rgb(188, 182, 173);
        }
        html.writer-html4 .rst-content dl:not(.docutils) dl:not(.field-list) > dt,
        html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) dl:not(.field-list) > dt {
            border-color: currentcolor currentcolor currentcolor rgb(118, 110, 97);
            background-color: rgb(26, 28, 29);
            background-image: none;
            color: rgb(178, 172, 162);
        }
        html.writer-html4 .rst-content dl:not(.docutils) dl:not(.field-list) > dt .headerlink,
        html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) dl:not(.field-list) > dt .headerlink {
            color: rgb(188, 182, 173);
        }
        html.writer-html4 .rst-content dl:not(.docutils) code.descclassname,
        html.writer-html4 .rst-content dl:not(.docutils) code.descname,
        html.writer-html4 .rst-content dl:not(.docutils) tt.descclassname,
        html.writer-html4 .rst-content dl:not(.docutils) tt.descname,
        html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) code.descclassname,
        html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) code.descname,
        html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) tt.descclassname,
        html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) tt.descname {
            background-color: transparent;
            border-color: currentcolor;
        }
        html.writer-html4 .rst-content dl:not(.docutils) .optional,
        html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) .optional {
            color: rgb(216, 212, 207);
        }
        .rst-content .viewcode-back,
        .rst-content .viewcode-link {
            color: rgb(99, 220, 150);
        }
        .rst-content code.download,
        .rst-content tt.download {
            background-color: inherit;
            background-image: inherit;
            color: inherit;
            border-color: inherit;
        }
        .rst-content .guilabel {
            border-color: rgb(38, 119, 172);
            background-color: rgb(26, 28, 29); background-image: none;
        }
        span[id*="MathJax-Span"] {
            color: rgb(188, 182, 173);
        }
        td.linenos .normal {
            color: inherit;
            background-color: transparent;
        }
        span.linenos {
            color: inherit;
            background-color: transparent;
        }
        td.linenos .special {
            color: rgb(216, 212, 207);
            background-color: rgb(71, 71, 0);
        }
        span.linenos.special {
            color: rgb(216, 212, 207);
            background-color: rgb(71, 71, 0);
        }
        .highlight .hll {
            background-color: rgb(66, 66, 0);
        }
        .highlight {
            background-color: rgb(32, 34, 36);
            background-image: none;
        }
        .highlight .c {
            color: rgb(124, 182, 197);
        }
        .highlight .err {
            border-color: rgb(201, 0, 0);
        }
        .highlight .k {
            color: rgb(114, 255, 154);
        }
        .highlight .o {
            color: rgb(171, 164, 153);
        }
        .highlight .ch {
            color: rgb(124, 182, 197);
        }
        .highlight .cm {
            color: rgb(124, 182, 197);
        }
        .highlight .cp {
            color: rgb(114, 255, 154);
        }
        .highlight .cpf {
            color: rgb(124, 182, 197);
        }
        .highlight .c1 {
            color: rgb(124, 182, 197);
        }
        .highlight .cs {
            color: rgb(124, 182, 197);
            background-color: rgb(48, 0, 0);
        }
        .highlight .gd {
            color: rgb(255, 90, 90);
        }
        .highlight .gr {
            color: rgb(255, 44, 44);
        }
        .highlight .gh {
            color: rgb(114, 185, 255);
        }
        .highlight .gi {
            color: rgb(90, 255, 90);
        }
        .highlight .go {
            color: rgb(193, 188, 180);
        }
        .highlight .gp {
            color: rgb(246, 151, 75);
        }
        .highlight .gu {
            color: rgb(255, 105, 255);
        }
        .highlight .gt {
            color: rgb(75, 173, 255);
        }
        .highlight .kc {
            color: rgb(114, 255, 154);
        }
        .highlight .kd {
            color: rgb(114, 255, 154);
        }
        .highlight .kn {
            color: rgb(114, 255, 154);
        }
        .highlight .kp {
            color: rgb(114, 255, 154);
        }
        .highlight .kr {
            color: rgb(114, 255, 154);
        }
        .highlight .kt {
            color: rgb(255, 133, 98);
        }
        .highlight .m {
            color: rgb(123, 222, 173);
        }
        .highlight .s {
            color: rgb(126, 170, 203);
        }
        .highlight .na {
            color: rgb(126, 170, 203);
        }
        .highlight .nb {
            color: rgb(114, 255, 154);
        }
        .highlight .nc {
            color: rgb(86, 196, 242);
        }
        .highlight .no {
            color: rgb(108, 180, 216);
        }
        .highlight .nd {
            color: rgb(178, 172, 162);
        }
        .highlight .ni {
            color: rgb(220, 111, 85);
        }
        .highlight .ne {
            color: rgb(114, 255, 154);
        }
        .highlight .nf {
            color: rgb(120, 189, 248);
        }
        .highlight .nl {
            color: rgb(121, 194, 255);
        }
        .highlight .nn {
            color: rgb(86, 196, 242);
        }
        .highlight .nt {
            color: rgb(125, 192, 248);
        }
        .highlight .nv {
            color: rgb(192, 108, 216);
        }
        .highlight .ow {
            color: rgb(114, 255, 154);
        }
        .highlight .w {
            color: rgb(186, 180, 171);
        }
        .highlight .mb {
            color: rgb(123, 222, 173);
        }
        .highlight .mf {
            color: rgb(123, 222, 173);
        }
        .highlight .mh {
            color: rgb(123, 222, 173);
        }
        .highlight .mi {
            color: rgb(123, 222, 173);
        }
        .highlight .mo {
            color: rgb(123, 222, 173);
        }
        .highlight .sa {
            color: rgb(126, 170, 203);
        }
        .highlight .sb {
            color: rgb(126, 170, 203);
        }
        .highlight .sc {
            color: rgb(126, 170, 203);
        }
        .highlight .dl {
            color: rgb(126, 170, 203);
        }
        .highlight .sd {
            color: rgb(126, 170, 203);
        }
        .highlight .s2 {
            color: rgb(126, 170, 203);
        }
        .highlight .se {
            color: rgb(126, 170, 203);
        }
        .highlight .sh {
            color: rgb(126, 170, 203);
        }
        .highlight .si {
            color: rgb(120, 172, 210);
        }
        .highlight .sx {
            color: rgb(246, 151, 75);
        }
        .highlight .sr {
            color: rgb(129, 182, 223);
        }
        .highlight .s1 {
            color: rgb(126, 170, 203);
        }
        .highlight .ss {
            color: rgb(186, 229, 123);
        }
        .highlight .bp {
            color: rgb(114, 255, 154);
        }
        .highlight .fm {
            color: rgb(120, 189, 248);
        }
        .highlight .vc {
            color: rgb(192, 108, 216);
        }
        .highlight .vg {
            color: rgb(192, 108, 216);
        }
        .highlight .vi {
            color: rgb(192, 108, 216);
        }
        .highlight .vm {
            color: rgb(192, 108, 216);
        }
        .highlight .il {
            color: rgb(123, 222, 173);
        }
        .rst-other-versions a {
            border-color: currentcolor;
        }
        .ethical-sidebar .ethical-image-link,
        .ethical-footer .ethical-image-link {
            border-color: currentcolor;
        }
        .ethical-sidebar,
        .ethical-footer {
            background-color: rgb(27, 29, 30);
            border-color: rgb(118, 110, 97);
            color: rgb(211, 208, 202);
        }
        .ethical-sidebar ul {
            list-style-image: none;
        }
        .ethical-sidebar ul li {
            background-color: rgb(4, 62, 97);
            color: rgb(216, 212, 207);
        }
        .ethical-sidebar a,
        .ethical-sidebar a:visited,
        .ethical-sidebar a:hover,
        .ethical-sidebar a:active,
        .ethical-footer a,
        .ethical-footer a:visited,
        .ethical-footer a:hover,
        .ethical-footer a:active {
            color: rgb(211, 208, 202);
            text-decoration-color: currentcolor !important;
            border-bottom-color: currentcolor !important;
        }
        .ethical-callout a {
            color: rgb(166, 159, 147) !important;
            text-decoration-color: currentcolor !important;
        }
        .ethical-fixedfooter {
            background-color: rgb(27, 29, 30);
            border-top-color: rgb(117, 109, 96);
            color: rgb(188, 182, 173);
        }
        .ethical-fixedfooter .ethical-text::before {
            background-color: rgb(49, 112, 51);
            color: rgb(216, 212, 207);
        }
        .ethical-fixedfooter .ethical-callout {
            color: rgb(171, 164, 153);
        }
        .ethical-fixedfooter a,
        .ethical-fixedfooter a:hover,
        .ethical-fixedfooter a:active,
        .ethical-fixedfooter a:visited {
            color: rgb(188, 182, 173);
            text-decoration-color: currentcolor;
        }
        .ethical-rtd .ethical-sidebar {
            color: rgb(182, 176, 167);
        }
        .ethical-alabaster a.ethical-image-link {
            border-color: currentcolor !important;
        }
        .ethical-dark-theme .ethical-sidebar {
            background-color: rgb(46, 50, 52);
            border-color: rgb(114, 106, 93);
            color: rgb(189, 183, 174) !important;
        }
        .ethical-dark-theme a,
        .ethical-dark-theme a:visited {
            color: rgb(205, 200, 194) !important;
            border-bottom-color: currentcolor !important;
        }
        .ethical-dark-theme .ethical-callout a {
            color: rgb(182, 176, 167) !important;
        }
        .keep-us-sustainable {
            border-color: rgb(104, 158, 45);
        }
        .keep-us-sustainable a,
        .keep-us-sustainable a:hover,
        .keep-us-sustainable a:visited {
            text-decoration-color: currentcolor;
        }
        .wy-nav-side .keep-us-sustainable {
            color: rgb(182, 176, 167);
        }
        .wy-nav-side .keep-us-sustainable a {
            color: rgb(209, 205, 199);
        }
        [data-ea-publisher].loaded a,
        [data-ea-type].loaded a {
            text-decoration-color: currentcolor;
        }
        [data-ea-publisher].loaded .ea-content,
        [data-ea-type].loaded .ea-content {
            background-color: rgba(0, 0, 0, 0.03);
            background-image: none;
            color: rgb(181, 174, 164);
        }
        [data-ea-publisher].loaded .ea-content a:link,
        [data-ea-type].loaded .ea-content a:link {
            color: rgb(181, 174, 164);
        }
        [data-ea-publisher].loaded .ea-content a:visited,
        [data-ea-type].loaded .ea-content a:visited {
            color: rgb(181, 174, 164);
        }
        [data-ea-publisher].loaded .ea-content a:hover,
        [data-ea-type].loaded .ea-content a:hover {
            color: rgb(192, 186, 178);
        }
        [data-ea-publisher].loaded .ea-content a:active,
        [data-ea-type].loaded .ea-content a:active {
            color: rgb(192, 186, 178);
        }
        [data-ea-publisher].loaded .ea-content a strong,
        [data-ea-publisher].loaded .ea-content a b,
        [data-ea-type].loaded .ea-content a strong,
        [data-ea-type].loaded .ea-content a b {
            color: rgb(64, 180, 248);
        }
        [data-ea-publisher].loaded .ea-callout a:link,
        [data-ea-type].loaded .ea-callout a:link {
            color: rgb(169, 162, 151);
        }
        [data-ea-publisher].loaded .ea-callout a:visited,
        [data-ea-type].loaded .ea-callout a:visited {
            color: rgb(169, 162, 151);
        }
        [data-ea-publisher].loaded .ea-callout a:hover,
        [data-ea-type].loaded .ea-callout a:hover {
            color: rgb(181, 174, 164);
        }
        [data-ea-publisher].loaded .ea-callout a:active,
        [data-ea-type].loaded .ea-callout a:active {
            color: rgb(181, 174, 164);
        }
        [data-ea-publisher].loaded .ea-callout a strong,
        [data-ea-publisher].loaded .ea-callout a b,
        [data-ea-type].loaded .ea-callout a strong,
        [data-ea-type].loaded .ea-callout a b {
            color: rgb(64, 180, 248);
        }
        [data-ea-publisher].loaded.dark .ea-content,
        [data-ea-type].loaded.dark .ea-content {
            background-color: rgba(19, 21, 22, 0.05);
            background-image: none;
            color: rgb(200, 196, 189);
        }
        [data-ea-publisher].loaded.dark .ea-content a:link,
        [data-ea-type].loaded.dark .ea-content a:link {
            color: rgb(200, 196, 189);
        }
        [data-ea-publisher].loaded.dark .ea-content a:visited,
        [data-ea-type].loaded.dark .ea-content a:visited {
            color: rgb(200, 196, 189);
        }
        [data-ea-publisher].loaded.dark .ea-content a:hover,
        [data-ea-type].loaded.dark .ea-content a:hover {
            color: rgb(212, 208, 202);
        }
        [data-ea-publisher].loaded.dark .ea-content a:active,
        [data-ea-type].loaded.dark .ea-content a:active {
            color: rgb(212, 208, 202);
        }
        [data-ea-publisher].loaded.dark .ea-content a strong,
        [data-ea-publisher].loaded.dark .ea-content a b,
        [data-ea-type].loaded.dark .ea-content a strong,
        [data-ea-type].loaded.dark .ea-content a b {
            color: rgb(85, 188, 249);
        }
        [data-ea-publisher].loaded.dark .ea-callout a:link,
        [data-ea-type].loaded.dark .ea-callout a:link {
            color: rgb(189, 184, 175);
        }
        [data-ea-publisher].loaded.dark .ea-callout a:visited,
        [data-ea-type].loaded.dark .ea-callout a:visited {
            color: rgb(189, 184, 175);
        }
        [data-ea-publisher].loaded.dark .ea-callout a:hover,
        [data-ea-type].loaded.dark .ea-callout a:hover {
            color: rgb(200, 196, 189);
        }
        [data-ea-publisher].loaded.dark .ea-callout a:active,
        [data-ea-type].loaded.dark .ea-callout a:active {
            color: rgb(200, 196, 189);
        }
        [data-ea-publisher].loaded.dark .ea-callout a strong,
        [data-ea-publisher].loaded.dark .ea-callout a b,
        [data-ea-type].loaded.dark .ea-callout a strong,
        [data-ea-type].loaded.dark .ea-callout a b {
            color: rgb(85, 188, 249);
        }
        @media (prefers-color-scheme: dark) {
            [data-ea-publisher].loaded.adaptive .ea-content,
            [data-ea-type].loaded.adaptive .ea-content {
                background-color: rgba(19, 21, 22, 0.05);
                background-image: none;
                color: rgb(200, 196, 189);
            }
            [data-ea-publisher].loaded.adaptive .ea-content a:link,
            [data-ea-type].loaded.adaptive .ea-content a:link {
                color: rgb(200, 196, 189);
            }
            [data-ea-publisher].loaded.adaptive .ea-content a:visited,
            [data-ea-type].loaded.adaptive .ea-content a:visited {
                color: rgb(200, 196, 189);
            }
            [data-ea-publisher].loaded.adaptive .ea-content a:hover,
            [data-ea-type].loaded.adaptive .ea-content a:hover {
                color: rgb(212, 208, 202);
            }
            [data-ea-publisher].loaded.adaptive .ea-content a:active,
            [data-ea-type].loaded.adaptive .ea-content a:active {
                color: rgb(212, 208, 202);
            }
            [data-ea-publisher].loaded.adaptive .ea-content a strong,
            [data-ea-publisher].loaded.adaptive .ea-content a b,
            [data-ea-type].loaded.adaptive .ea-content a strong,
            [data-ea-type].loaded.adaptive .ea-content a b {
                color: rgb(85, 188, 249);
            }
            [data-ea-publisher].loaded.adaptive .ea-callout a:link,
            [data-ea-type].loaded.adaptive .ea-callout a:link {
                color: rgb(189, 184, 175);
            }
            [data-ea-publisher].loaded.adaptive .ea-callout a:visited,
            [data-ea-type].loaded.adaptive .ea-callout a:visited {
                color: rgb(189, 184, 175);
            }
            [data-ea-publisher].loaded.adaptive .ea-callout a:hover,
            [data-ea-type].loaded.adaptive .ea-callout a:hover {
                color: rgb(200, 196, 189);
            }
            [data-ea-publisher].loaded.adaptive .ea-callout a:active,
            [data-ea-type].loaded.adaptive .ea-callout a:active {
                color: rgb(200, 196, 189);
            }
            [data-ea-publisher].loaded.adaptive .ea-callout a strong,
            [data-ea-publisher].loaded.adaptive .ea-callout a b,
            [data-ea-type].loaded.adaptive .ea-callout a strong,
            [data-ea-type].loaded.adaptive .ea-callout a b {
                color: rgb(85, 188, 249);
            }
        }
        [data-ea-publisher].loaded .ea-content,
        [data-ea-type].loaded .ea-content {
            border-color: currentcolor;
            box-shadow: rgba(0, 0, 0, 0.15) 0px 2px 3px;
        }
        [data-ea-publisher].loaded.raised .ea-content,
        [data-ea-type].loaded.raised .ea-content {
            border-color: currentcolor;
            box-shadow: rgba(0, 0, 0, 0.15) 0px 2px 3px;
        }
        [data-ea-publisher].loaded.bordered .ea-content,
        [data-ea-type].loaded.bordered .ea-content {
            border-color: rgba(84, 91, 95, 0.04);
            box-shadow: none;
        }
        [data-ea-publisher].loaded.bordered.dark .ea-content,
        [data-ea-type].loaded.bordered.dark .ea-content {
            border-color: rgba(123, 114, 101, 0.07);
        }
        @media (prefers-color-scheme: dark) {
            [data-ea-publisher].loaded.bordered.adaptive .ea-content,
            [data-ea-type].loaded.bordered.adaptive .ea-content {
                border-color: rgba(123, 114, 101, 0.07);
            }
        }
        [data-ea-publisher].loaded.flat .ea-content,
        [data-ea-type].loaded.flat .ea-content {
            border-color: currentcolor;
            box-shadow: none;
        }
        .vimvixen-hint {
            background-color: rgb(98, 66, 0) !important;
            border-color: rgb(170, 138, 15) !important;
            color: rgb(237, 221, 175) !important;
        }
        #edge-translate-panel-body {
            color: var(--darkreader-text--darkreader-neutral-text) !important;
        }
    }

    /* Override Style */
    .vimvixen-hint {
        background-color: #7b5300 !important;
        border-color: #d8b013 !important;
        color: #f3e8c8 !important;
    }
    ::placeholder {
        opacity: 0.5 !important;
    }
    a[href="https://coinmarketcap.com/"] > svg[width="94"][height="16"] > path {
        fill: var(--darkreader-neutral-text) !important;
    }
    #edge-translate-panel-body {
        color: var(--darkreader-neutral-text) !important;
    }

}